# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in New Hampshire."""


BELKNAP = "001"
CARROLL = "003"
CHESHIRE = "005"
COOS = "007"
GRAFTON = "009"
HILLSBOROUGH = "011"
MERRIMACK = "013"
ROCKINGHAM = "015"
STRAFFORD = "017"
SULLIVAN = "019"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Michigan."""


ADDISON_VILLAGE = "00380"
ADRIAN_CITY = "00440"
ADVANCE_CDP = "00480"
AHMEEK_VILLAGE = "00620"
AKRON_VILLAGE = "00700"
ALANSON_VILLAGE = "00860"
ALBA_CDP = "00900"
ALBION_CITY = "00980"
ALDEN_CDP = "01060"
ALGONAC_CITY = "01180"
ALLEGAN_CITY = "01260"
ALLEN_PARK_CITY = "01380"
ALLEN_VILLAGE = "01300"
ALLENDALE_CDP = "01340"
ALMA_CITY = "01540"
ALMONT_VILLAGE = "01660"
ALPENA_CITY = "01740"
ALPHA_VILLAGE = "01800"
AMASA_CDP = "01960"
ANN_ARBOR_CITY = "03000"
APPLEGATE_VILLAGE = "03200"
ARCADIA_CDP = "03300"
ARGENTINE_CDP = "03400"
ARMADA_VILLAGE = "03520"
ASHLEY_VILLAGE = "03740"
ATHENS_VILLAGE = "03880"
ATLANTA_CDP = "03920"
ATLANTIC_MINE_CDP = "03960"
ATTICA_CDP = "04020"
AU_GRES_CITY = "04120"
AU_SABLE_CDP = "04280"
AUBURN_HILLS_CITY = "04105"
AUBURN_CITY = "04080"
AUGUSTA_VILLAGE = "04160"
BAD_AXE_CITY = "04740"
BALDWIN_VILLAGE = "04940"
BANCROFT_VILLAGE = "05080"
BANGOR_CITY = "05140"
BARAGA_VILLAGE = "05320"
BARNES_LAKE_CDP = "05466"
BARODA_VILLAGE = "05500"
BARRYTON_VILLAGE = "05580"
BARTON_HILLS_VILLAGE = "05660"
BATH_CDP = "05880"
BATTLE_CREEK_CITY = "05920"
BAY_CITY_CITY = "06020"
BAY_PORT_CDP = "06120"
BAY_SHORE_CDP = "06180"
BAY_VIEW_CDP = "06260"
BEAL_CITY_CDP = "06360"
BEAR_LAKE_CDP = "06430"
BEAR_LAKE_VILLAGE = "06460"
BEAVERTON_CITY = "06660"
BEECHER_CDP = "06820"
BEECHWOOD_CDP = "06880"
BELDING_CITY = "06900"
BELLAIRE_VILLAGE = "06980"
BELLEVILLE_CITY = "07020"
BELLEVUE_VILLAGE = "07060"
BENDON_CDP = "07220"
BENTON_HARBOR_CITY = "07520"
BENTON_HEIGHTS_CDP = "07540"
BENZONIA_VILLAGE = "07580"
BERGLAND_CDP = "07620"
BERKLEY_CITY = "07660"
BERRIEN_SPRINGS_VILLAGE = "07860"
BESSEMER_CITY = "07960"
BEULAH_VILLAGE = "08100"
BEVERLY_HILLS_VILLAGE = "08160"
BIG_BAY_CDP = "08180"
BIG_RAPIDS_CITY = "08300"
BINGHAM_FARMS_VILLAGE = "08460"
BIRCH_RUN_VILLAGE = "08540"
BIRMINGHAM_CITY = "08640"
BLISSFIELD_VILLAGE = "09000"
BLOOMFIELD_HILLS_CITY = "09180"
BLOOMINGDALE_VILLAGE = "09220"
BOON_CDP = "09560"
BOYNE_CITY_CITY = "09820"
BOYNE_FALLS_VILLAGE = "09840"
BRECKENRIDGE_VILLAGE = "10160"
BREEDSVILLE_VILLAGE = "10180"
BRETHREN_CDP = "10300"
BRIDGEPORT_CDP = "10440"
BRIDGMAN_CITY = "10580"
BRIGHTON_CITY = "10620"
BRIMLEY_CDP = "10680"
BRITTON_VILLAGE = "10760"
BRONSON_CITY = "10860"
BROOKLYN_VILLAGE = "11000"
BROWN_CITY_CITY = "11180"
BROWNLEE_PARK_CDP = "11200"
BRUCE_CROSSING_CDP = "11320"
BRUTUS_CDP = "11380"
BUCHANAN_CITY = "11400"
BUCKLEY_VILLAGE = "11480"
BUENA_VISTA_CDP = "11555"
BURLINGTON_VILLAGE = "11800"
BURR_OAK_VILLAGE = "11920"
BURT_CDP = "12000"
BURTON_CITY = "12060"
BYRON_CENTER_CDP = "12280"
BYRON_VILLAGE = "12260"
CABERFAE_CDP = "12290"
CADILLAC_CITY = "12320"
CALEDONIA_VILLAGE = "12480"
CALUMET_VILLAGE = "12580"
CAMBRIA_CDP = "12680"
CAMDEN_VILLAGE = "12760"
CANADA_CREEK_RANCH_CDP = "12980"
CANADIAN_LAKES_CDP = "13010"
CANNONSBURG_CDP = "13100"
CAPAC_VILLAGE = "13140"
CARLETON_VILLAGE = "13220"
CARNEY_VILLAGE = "13400"
CARO_CITY = "13420"
CARP_LAKE_CDP = "13480"
CARSON_CITY_CITY = "13600"
CARSONVILLE_VILLAGE = "13620"
CASEVILLE_CITY = "13760"
CASNOVIA_VILLAGE = "13820"
CASPIAN_CITY = "13860"
CASS_CITY_VILLAGE = "13880"
CASSOPOLIS_VILLAGE = "13900"
CEDAR_CDP = "14020"
CEDAR_SPRINGS_CITY = "14200"
CEMENT_CITY_VILLAGE = "14260"
CENTER_LINE_CITY = "14320"
CENTRAL_LAKE_VILLAGE = "14400"
CENTREVILLE_VILLAGE = "14460"
CHARLEVOIX_CITY = "14780"
CHARLOTTE_CITY = "14820"
CHASSELL_CDP = "14900"
CHATHAM_VILLAGE = "14940"
CHEBOYGAN_CITY = "15000"
CHELSEA_CITY = "15020"
CHESANING_VILLAGE = "15140"
CHUMS_CORNER_CDP = "15715"
CLARE_CITY = "15920"
CLARKSVILLE_VILLAGE = "16140"
CLAWSON_CITY = "16160"
CLAYTON_VILLAGE = "16280"
CLIFFORD_VILLAGE = "16420"
CLIMAX_VILLAGE = "16440"
CLINTON_VILLAGE = "16480"
CLIO_CITY = "16620"
COLDWATER_CITY = "17020"
COLEMAN_CITY = "17100"
COLOMA_CITY = "17320"
COLON_VILLAGE = "17360"
COLUMBIAVILLE_VILLAGE = "17460"
COMSTOCK_NORTHWEST_CDP = "17690"
COMSTOCK_PARK_CDP = "17700"
CONCORD_VILLAGE = "17740"
CONSTANTINE_VILLAGE = "17840"
CONWAY_CDP = "17900"
COOPERSVILLE_CITY = "18020"
COPEMISH_VILLAGE = "18040"
COPPER_CITY_VILLAGE = "18080"
COPPER_HARBOR_CDP = "18100"
CORUNNA_CITY = "18300"
COVINGTON_CDP = "18580"
CROSS_VILLAGE_CDP = "18880"
CROSWELL_CITY = "18920"
CRYSTAL_CDP = "19060"
CRYSTAL_DOWNS_COUNTRY_CLUB_CDP = "19135"
CRYSTAL_FALLS_CITY = "19140"
CRYSTAL_MOUNTAIN_CDP = "19195"
CUSTER_VILLAGE = "19420"
CUTLERVILLE_CDP = "19500"
DAGGETT_VILLAGE = "19560"
DANSVILLE_VILLAGE = "19780"
DAVISON_CITY = "19880"
DE_TOUR_VILLAGE_VILLAGE = "21780"
DEWITT_CITY = "22120"
DEARBORN_HEIGHTS_CITY = "21020"
DEARBORN_CITY = "21000"
DECATUR_VILLAGE = "21040"
DECKERVILLE_VILLAGE = "21100"
DEERFIELD_VILLAGE = "21180"
DELTON_CDP = "21560"
DETROIT_BEACH_CDP = "22040"
DETROIT_CITY = "22000"
DEXTER_CITY = "22160"
DIMONDALE_VILLAGE = "22380"
DODGEVILLE_CDP = "22500"
DOLLAR_BAY_CDP = "22520"
DORR_CDP = "22660"
DOUGLAS_CITY = "22740"
DOWAGIAC_CITY = "22880"
DOWLING_CDP = "22900"
DRYDEN_VILLAGE = "23140"
DUNDEE_VILLAGE = "23380"
DURAND_CITY = "23500"
EAGLE_HARBOR_CDP = "23600"
EAGLE_RIVER_CDP = "23740"
EAGLE_VILLAGE = "23560"
EAST_GRAND_RAPIDS_CITY = "23980"
EAST_JORDAN_CITY = "24020"
EAST_LANSING_CITY = "24120"
EAST_TAWAS_CITY = "24420"
EASTLAKE_VILLAGE = "24060"
EASTPOINTE_CITY = "24290"
EASTPORT_CDP = "24300"
EASTWOOD_CDP = "24500"
EATON_RAPIDS_CITY = "24540"
EAU_CLAIRE_VILLAGE = "24580"
ECORSE_CITY = "24740"
EDGEMONT_PARK_CDP = "24880"
EDMORE_VILLAGE = "25000"
EDWARDSBURG_VILLAGE = "25040"
ELBERTA_VILLAGE = "25180"
ELK_RAPIDS_VILLAGE = "25320"
ELKTON_VILLAGE = "25360"
ELLSWORTH_VILLAGE = "25420"
ELM_HALL_CDP = "25580"
ELSIE_VILLAGE = "25780"
EMMETT_VILLAGE = "25940"
EMPIRE_VILLAGE = "25980"
ESCANABA_CITY = "26360"
ESSEXVILLE_CITY = "26420"
ESTRAL_BEACH_VILLAGE = "26460"
EUREKA_CDP = "26500"
EVART_CITY = "26640"
EWEN_CDP = "26820"
FAIR_PLAIN_CDP = "27160"
FAIRGROVE_VILLAGE = "27080"
FALMOUTH_CDP = "27320"
FARMINGTON_HILLS_CITY = "27440"
FARMINGTON_CITY = "27380"
FARWELL_VILLAGE = "27500"
FENNVILLE_CITY = "27740"
FENTON_CITY = "27760"
FERNDALE_CITY = "27880"
FERRYSBURG_CITY = "27960"
FIFE_LAKE_VILLAGE = "28000"
FILER_CITY_CDP = "28060"
FLAT_ROCK_CITY = "28360"
FLINT_CITY = "29000"
FLUSHING_CITY = "29200"
FOREST_HILLS_CDP = "29580"
FORESTVILLE_VILLAGE = "29660"
FOSTORIA_CDP = "29920"
FOUNTAIN_VILLAGE = "29940"
FOWLER_VILLAGE = "30040"
FOWLERVILLE_VILLAGE = "30060"
FRANKENMUTH_CITY = "30200"
FRANKFORT_CITY = "30260"
FRANKLIN_VILLAGE = "30340"
FRASER_CITY = "30420"
FREE_SOIL_VILLAGE = "30600"
FREELAND_CDP = "30540"
FREEPORT_VILLAGE = "30580"
FREMONT_CITY = "30700"
FRUITPORT_VILLAGE = "31000"
FULTON_CDP = "31120"
GAASTRA_CITY = "31160"
GAGETOWN_VILLAGE = "31180"
GAINES_VILLAGE = "31200"
GALESBURG_CITY = "31260"
GALIEN_VILLAGE = "31300"
GARDEN_CITY_CITY = "31420"
GARDEN_VILLAGE = "31380"
GAYLORD_CITY = "31720"
GIBRALTAR_CITY = "32020"
GLADSTONE_CITY = "32300"
GLADWIN_CITY = "32320"
GLEN_ARBOR_CDP = "32360"
GOBLES_CITY = "32640"
GOODRICH_VILLAGE = "32980"
GRAND_BEACH_VILLAGE = "33260"
GRAND_BLANC_CITY = "33280"
GRAND_HAVEN_CITY = "33340"
GRAND_LEDGE_CITY = "33420"
GRAND_MARAIS_CDP = "33440"
GRAND_RAPIDS_CITY = "34000"
GRANDVILLE_CITY = "34160"
GRANT_CITY = "34360"
GRASS_LAKE_VILLAGE = "34480"
GRAWN_CDP = "34620"
GRAYLING_CITY = "34640"
GREENLAND_CDP = "34980"
GREENVILLE_CITY = "35100"
GREILICKVILLE_CDP = "35300"
GROSSE_POINTE_FARMS_CITY = "35520"
GROSSE_POINTE_PARK_CITY = "35540"
GROSSE_POINTE_WOODS_CITY = "35580"
GROSSE_POINTE_CITY = "35480"
GWINN_CDP = "35760"
HAMTRAMCK_CITY = "36280"
HANCOCK_CITY = "36300"
HANOVER_VILLAGE = "36380"
HARBOR_BEACH_CITY = "36460"
HARBOR_SPRINGS_CITY = "36560"
HARDWOOD_ACRES_CDP = "36585"
HARING_CDP = "36590"
HARPER_WOODS_CITY = "36700"
HARRIETTA_VILLAGE = "36720"
HARRISON_CITY = "36800"
HARRISVILLE_CITY = "36860"
HART_CITY = "36920"
HARTFORD_CITY = "36960"
HARTLAND_CDP = "37020"
HARVEY_CDP = "37080"
HASLETT_CDP = "37100"
HASTINGS_CITY = "37120"
HAZEL_PARK_CITY = "37420"
HEMLOCK_CDP = "37600"
HENDERSON_CDP = "37620"
HERMANSVILLE_CDP = "37760"
HERSEY_VILLAGE = "37820"
HESPERIA_VILLAGE = "37860"
HICKORY_CORNERS_CDP = "37960"
HIGHLAND_PARK_CITY = "38180"
HILLMAN_VILLAGE = "38380"
HILLSDALE_CITY = "38460"
HOLLAND_CITY = "38640"
HOLLY_VILLAGE = "38700"
HOLT_CDP = "38780"
HOMER_VILLAGE = "38920"
HONOR_VILLAGE = "39080"
HOPKINS_VILLAGE = "39180"
HORTON_BAY_CDP = "39340"
HOUGHTON_LAKE_CDP = "39400"
HOUGHTON_CITY = "39360"
HOWARD_CITY_VILLAGE = "39500"
HOWELL_CITY = "39540"
HUBBARD_LAKE_CDP = "39634"
HUBBARDSTON_VILLAGE = "39660"
HUBBELL_CDP = "39680"
HUDSON_CITY = "39720"
HUDSONVILLE_CITY = "39800"
HUNTINGTON_WOODS_CITY = "40000"
HURONTOWN_CDP = "40160"
IDA_CDP = "40240"
IMLAY_CITY_CITY = "40320"
INDIAN_RIVER_CDP = "40480"
INKSTER_CITY = "40680"
INTERLOCHEN_CDP = "40800"
IONIA_CITY = "40860"
IRON_MOUNTAIN_CITY = "40960"
IRON_RIVER_CITY = "40980"
IRONTON_CDP = "41040"
IRONWOOD_CITY = "41060"
ISHPEMING_CITY = "41220"
ITHACA_CITY = "41340"
JACKSON_CITY = "41420"
JASPER_CDP = "41540"
JENISON_CDP = "41680"
JENNINGS_CDP = "41720"
JONESVILLE_CITY = "41920"
K_I_SAWYER_CDP = "43558"
KALAMAZOO_CITY = "42160"
KALEVA_VILLAGE = "42240"
KALKASKA_VILLAGE = "42260"
KEEGO_HARBOR_CITY = "42460"
KENT_CITY_VILLAGE = "42780"
KENTWOOD_CITY = "42820"
KINCHELOE_CDP = "43180"
KINDE_VILLAGE = "43220"
KINGSFORD_CITY = "43300"
KINGSLEY_VILLAGE = "43340"
KINGSTON_VILLAGE = "43380"
LANSE_VILLAGE = "45540"
LAINGSBURG_CITY = "44200"
LAKE_ANGELUS_CITY = "44440"
LAKE_ANN_VILLAGE = "44460"
LAKE_CITY_CITY = "44480"
LAKE_FENTON_CDP = "44520"
LAKE_GOGEBIC_CDP = "44620"
LAKE_ISABELLA_VILLAGE = "44715"
LAKE_LEANN_CDP = "44752"
LAKE_LEELANAU_CDP = "44760"
LAKE_LINDEN_VILLAGE = "44780"
LAKE_MICHIGAN_BEACH_CDP = "44820"
LAKE_ODESSA_VILLAGE = "44880"
LAKE_ORION_VILLAGE = "44940"
LAKE_VICTORIA_CDP = "45190"
LAKEPORT_CDP = "45000"
LAKES_OF_THE_NORTH_CDP = "45144"
LAKEVIEW_VILLAGE = "45240"
LAKEWOOD_CLUB_VILLAGE = "45340"
LAMBERTVILLE_CDP = "45420"
LAMONT_CDP = "45440"
LANSING_CITY = "46000"
LAPEER_CITY = "46040"
LATHRUP_VILLAGE_CITY = "46320"
LAURIUM_VILLAGE = "46360"
LAWRENCE_VILLAGE = "46440"
LAWTON_VILLAGE = "46500"
LE_ROY_VILLAGE = "47100"
LELAND_CDP = "46800"
LENNON_VILLAGE = "46880"
LEONARD_VILLAGE = "46940"
LESLIE_CITY = "47180"
LEVEL_PARK_OAK_PARK_CDP = "47230"
LEVERING_CDP = "47240"
LEWISTON_CDP = "47260"
LEXINGTON_VILLAGE = "47280"
LINCOLN_PARK_CITY = "47800"
LINCOLN_VILLAGE = "47560"
LINDEN_CITY = "47820"
LITCHFIELD_CITY = "47980"
LIVONIA_CITY = "49000"
LOOMIS_CDP = "49400"
LOST_LAKE_WOODS_CDP = "49450"
LOWELL_CITY = "49540"
LUDINGTON_CITY = "49640"
LUNA_PIER_CITY = "49700"
LUPTON_CDP = "49720"
LUTHER_VILLAGE = "49740"
LYONS_VILLAGE = "49900"
MACKINAC_ISLAND_CITY = "50280"
MACKINAW_CITY_VILLAGE = "50320"
MADISON_HEIGHTS_CITY = "50560"
MANCELONA_VILLAGE = "50620"
MANCHESTER_VILLAGE = "50660"
MANISTEE_LAKE_CDP = "50755"
MANISTEE_CITY = "50720"
MANISTIQUE_CITY = "50760"
MANITOU_BEACH_DEVILS_LAKE_CDP = "50830"
MANTON_CITY = "50880"
MAPLE_CITY_CDP = "50920"
MAPLE_GROVE_CDP = "50970"
MAPLE_RAPIDS_VILLAGE = "51200"
MARCELLUS_VILLAGE = "51460"
MARENISCO_CDP = "51540"
MARINE_CITY_CITY = "51600"
MARION_VILLAGE = "51660"
MARLETTE_CITY = "51820"
MARQUETTE_CITY = "51900"
MARSHALL_CITY = "51940"
MARTIN_VILLAGE = "51980"
MARYSVILLE_CITY = "52080"
MASON_CITY = "52180"
MASS_CITY_CDP = "52280"
MATTAWAN_VILLAGE = "52380"
MAYBEE_VILLAGE = "52440"
MAYVILLE_VILLAGE = "52540"
MCBAIN_CITY = "49980"
MCBRIDE_VILLAGE = "50000"
MEARS_CDP = "52720"
MECOSTA_VILLAGE = "52760"
MELVIN_VILLAGE = "52920"
MELVINDALE_CITY = "52940"
MEMPHIS_CITY = "52960"
MENDON_VILLAGE = "52980"
MENOMINEE_CITY = "53020"
MERRILL_VILLAGE = "53180"
MESICK_VILLAGE = "53320"
METAMORA_VILLAGE = "53340"
MICHIANA_VILLAGE = "53500"
MICHIGAMME_CDP = "53520"
MICHIGAN_CENTER_CDP = "53580"
MIDDLETOWN_CDP = "53730"
MIDDLEVILLE_VILLAGE = "53760"
MIDLAND_CITY = "53780"
MILAN_CITY = "53920"
MILFORD_VILLAGE = "53960"
MILLBURG_CDP = "54025"
MILLERS_LAKE_CDP = "54132"
MILLERSBURG_VILLAGE = "54120"
MILLINGTON_VILLAGE = "54220"
MINDEN_CITY_VILLAGE = "54560"
MIO_CDP = "54660"
MOHAWK_CDP = "54820"
MONROE_CITY = "55020"
MONTAGUE_CITY = "55100"
MONTGOMERY_VILLAGE = "55220"
MONTROSE_CITY = "55280"
MORENCI_CITY = "55500"
MORLEY_VILLAGE = "55540"
MORRICE_VILLAGE = "55560"
MOUNT_CLEMENS_CITY = "55820"
MOUNT_MORRIS_CITY = "55960"
MOUNT_PLEASANT_CITY = "56020"
MUIR_VILLAGE = "56080"
MULLIKEN_VILLAGE = "56140"
MUNISING_CITY = "56200"
MUSKEGON_HEIGHTS_CITY = "56360"
MUSKEGON_CITY = "56320"
NAPOLEON_CDP = "56620"
NASHVILLE_VILLAGE = "56680"
NAUBINWAY_CDP = "56760"
NEGAUNEE_CITY = "56860"
NESSEN_CITY_CDP = "56960"
NEW_BALTIMORE_CITY = "57100"
NEW_BUFFALO_CITY = "57220"
NEW_ERA_VILLAGE = "57280"
NEW_HAVEN_VILLAGE = "57380"
NEW_LOTHROP_VILLAGE = "57520"
NEW_TROY_CDP = "57660"
NEWAYGO_CITY = "57080"
NEWBERRY_VILLAGE = "57140"
NILES_CITY = "57760"
NORTH_ADAMS_VILLAGE = "57920"
NORTH_BRANCH_VILLAGE = "58080"
NORTH_MUSKEGON_CITY = "58640"
NORTHPORT_VILLAGE = "58740"
NORTHVIEW_CDP = "58945"
NORTHVILLE_CITY = "58980"
NORTON_SHORES_CITY = "59140"
NORWAY_CITY = "59220"
NORWOOD_CDP = "59320"
NOVI_CITY = "59440"
NUNICA_CDP = "59520"
OAK_HILL_CDP = "59740"
OAK_PARK_CITY = "59920"
OAKLEY_VILLAGE = "59860"
ODEN_CDP = "60180"
OKEMOS_CDP = "60340"
OLIVET_CITY = "60580"
OMENA_CDP = "60640"
OMER_CITY = "60660"
ONAWAY_CITY = "60680"
ONEKAMA_VILLAGE = "60740"
ONSTED_VILLAGE = "60840"
ONTONAGON_VILLAGE = "60860"
ORCHARD_LAKE_VILLAGE_CITY = "61020"
ORTONVILLE_VILLAGE = "61220"
OSCODA_CDP = "61320"
OSSINEKE_CDP = "61500"
OTISVILLE_VILLAGE = "61600"
OTSEGO_CITY = "61620"
OTTER_LAKE_VILLAGE = "61760"
OVID_CITY = "61860"
OWENDALE_VILLAGE = "61920"
OWOSSO_CITY = "61940"
OXFORD_VILLAGE = "62020"
PAINESDALE_CDP = "62120"
PALMER_CDP = "62180"
PALO_CDP = "62260"
PARCHMENT_CITY = "62340"
PARIS_CDP = "62400"
PARKDALE_CDP = "62500"
PARMA_VILLAGE = "62740"
PAW_PAW_LAKE_CDP = "63020"
PAW_PAW_VILLAGE = "62980"
PEARL_BEACH_CDP = "63200"
PECK_VILLAGE = "63260"
PELKIE_CDP = "63280"
PELLSTON_VILLAGE = "63300"
PENTWATER_VILLAGE = "63540"
PERRINTON_VILLAGE = "63660"
PERRY_CITY = "63700"
PETERSBURG_CITY = "63800"
PETOSKEY_CITY = "63820"
PEWAMO_VILLAGE = "63900"
PIERSON_VILLAGE = "64020"
PIGEON_VILLAGE = "64060"
PILGRIM_CDP = "64100"
PINCKNEY_VILLAGE = "64140"
PINCONNING_CITY = "64160"
PITTSFORD_CDP = "64600"
PLAINWELL_CITY = "64740"
PLEASANT_RIDGE_CITY = "64900"
PLYMOUTH_CITY = "65060"
PONSHEWAING_CDP = "65420"
PONTIAC_CITY = "65440"
PORT_AUSTIN_VILLAGE = "65680"
PORT_HOPE_VILLAGE = "65800"
PORT_HURON_CITY = "65820"
PORT_SANILAC_VILLAGE = "65900"
PORTAGE_CITY = "65560"
PORTLAND_CITY = "65860"
POSEN_VILLAGE = "66000"
POTTERVILLE_CITY = "66100"
POWERS_VILLAGE = "66140"
PRESCOTT_VILLAGE = "66300"
PRESQUE_ISLE_HARBOR_CDP = "66343"
PRUDENVILLE_CDP = "66400"
QUINCY_VILLAGE = "66640"
QUINNESEC_CDP = "66720"
RAMSAY_CDP = "66980"
RAPID_CITY_CDP = "67140"
RAPID_RIVER_CDP = "67160"
RAVENNA_VILLAGE = "67280"
READING_CITY = "67500"
REED_CITY_CITY = "67820"
REESE_VILLAGE = "67900"
REPUBLIC_CDP = "67980"
RICHLAND_VILLAGE = "68240"
RICHMOND_CITY = "68380"
RIVER_ROUGE_CITY = "68760"
RIVERDALE_CDP = "68720"
RIVERVIEW_CITY = "68880"
ROBIN_GLEN_INDIANTOWN_CDP = "68990"
ROCHESTER_HILLS_CITY = "69035"
ROCHESTER_CITY = "69020"
ROCK_CDP = "69060"
ROCKFORD_CITY = "69080"
ROCKLAND_CDP = "69120"
ROCKWOOD_CITY = "69180"
ROGERS_CITY_CITY = "69260"
ROMEO_VILLAGE = "69400"
ROMULUS_CITY = "69420"
ROOSEVELT_PARK_CITY = "69520"
ROSCOMMON_VILLAGE = "69540"
ROSE_CITY_CITY = "69680"
ROSEBUSH_VILLAGE = "69640"
ROSEVILLE_CITY = "69800"
ROTHBURY_VILLAGE = "69880"
ROYAL_OAK_CITY = "70040"
RUBY_CDP = "70160"
SAGINAW_CITY = "70520"
SALINE_CITY = "71140"
SAND_LAKE_CDP = "71340"
SAND_LAKE_VILLAGE = "71360"
SANDUSKY_CITY = "71540"
SANFORD_VILLAGE = "71560"
SARANAC_VILLAGE = "71660"
SAUGATUCK_CITY = "71700"
SAULT_STE_MARIE_CITY = "71740"
SCHOOLCRAFT_VILLAGE = "71860"
SCOTTS_CDP = "72060"
SCOTTVILLE_CITY = "72080"
SEBEWAING_VILLAGE = "72180"
SHAFTSBURG_CDP = "72700"
SHELBY_VILLAGE = "72840"
SHEPHERD_VILLAGE = "72960"
SHERIDAN_VILLAGE = "73100"
SHERWOOD_VILLAGE = "73420"
SHIELDS_CDP = "73560"
SHOREHAM_VILLAGE = "73660"
SHOREWOOD_TOWER_HILLS_HARBERT_CDP = "73730"
SKANEE_CDP = "74120"
SKIDWAY_LAKE_CDP = "74200"
SNOVER_CDP = "74380"
SOUTH_BOARDMAN_CDP = "74740"
SOUTH_GULL_LAKE_CDP = "74975"
SOUTH_HAVEN_CITY = "74980"
SOUTH_LYON_CITY = "75100"
SOUTH_MONROE_CDP = "75140"
SOUTH_RANGE_VILLAGE = "75220"
SOUTH_ROCKWOOD_VILLAGE = "75280"
SOUTHFIELD_CITY = "74900"
SOUTHGATE_CITY = "74960"
SPARTA_VILLAGE = "75420"
SPRING_ARBOR_CDP = "75620"
SPRING_LAKE_VILLAGE = "75820"
SPRINGFIELD_CITY = "75700"
SPRINGPORT_VILLAGE = "75860"
ST_CHARLES_VILLAGE = "70640"
ST_CLAIR_SHORES_CITY = "70760"
ST_CLAIR_CITY = "70680"
ST_HELEN_CDP = "70800"
ST_IGNACE_CITY = "70840"
ST_JAMES_CDP = "70900"
ST_JOHNS_CITY = "70940"
ST_JOSEPH_CITY = "70960"
ST_LOUIS_CITY = "71000"
STANDISH_CITY = "76120"
STANTON_CITY = "76220"
STANWOOD_VILLAGE = "76240"
STEPHENSON_CITY = "76380"
STERLING_HEIGHTS_CITY = "76460"
STERLING_VILLAGE = "76420"
STEVENSVILLE_VILLAGE = "76500"
STOCKBRIDGE_VILLAGE = "76560"
STONY_POINT_CDP = "76720"
STRONACH_CDP = "76820"
STURGIS_CITY = "76960"
SUNFIELD_VILLAGE = "77420"
SUTTONS_BAY_VILLAGE = "77600"
SWARTZ_CREEK_CITY = "77700"
SYLVAN_LAKE_CITY = "77860"
TAWAS_CITY_CITY = "78140"
TAYLOR_CITY = "79000"
TECUMSEH_CITY = "79120"
TEKONSHA_VILLAGE = "79160"
TEMPERANCE_CDP = "79240"
THOMPSONVILLE_VILLAGE = "79600"
THREE_LAKES_CDP = "79680"
THREE_OAKS_VILLAGE = "79720"
THREE_RIVERS_CITY = "79760"
TOWER_CDP = "80200"
TRAVERSE_CITY_CITY = "80340"
TRENTON_CITY = "80420"
TRIMOUNTAIN_CDP = "80480"
TROWBRIDGE_PARK_CDP = "80660"
TROY_CITY = "80700"
TRUFANT_CDP = "80720"
TURNER_VILLAGE = "80820"
TUSTIN_VILLAGE = "80960"
TWIN_LAKE_CDP = "81040"
TWINING_VILLAGE = "81020"
UBLY_VILLAGE = "81200"
UNION_CITY_VILLAGE = "81360"
UNIONVILLE_VILLAGE = "81420"
UTICA_CITY = "81540"
VANDALIA_VILLAGE = "81680"
VANDERBILT_VILLAGE = "81700"
VANDERCOOK_LAKE_CDP = "81740"
VASSAR_CITY = "81840"
VERMONTVILLE_VILLAGE = "81960"
VERNON_VILLAGE = "82020"
VICKSBURG_VILLAGE = "82300"
VILLAGE_OF_CLARKSTON_CITY = "82450"
VILLAGE_OF_GROSSE_POINTE_SHORES_CITY = "82453"
VINEYARD_LAKE_CDP = "82490"
WACOUSTA_CDP = "82680"
WAKEFIELD_CITY = "82780"
WALDRON_VILLAGE = "82880"
WALKER_CITY = "82960"
WALKERVILLE_VILLAGE = "83020"
WALLED_LAKE_CITY = "83060"
WALLOON_LAKE_CDP = "83140"
WARREN_CITY = "84000"
WATERSMEET_CDP = "84360"
WATERVLIET_CITY = "84500"
WAVERLY_CDP = "84800"
WAYLAND_CITY = "84880"
WAYNE_CITY = "84940"
WEBBERVILLE_VILLAGE = "85080"
WEDGEWOOD_CDP = "85110"
WEIDMAN_CDP = "85140"
WELLSTON_CDP = "85300"
WEST_BRANCH_CITY = "85580"
WEST_ISHPEMING_CDP = "85700"
WEST_MONROE_CDP = "86050"
WESTLAND_CITY = "86000"
WESTPHALIA_VILLAGE = "86120"
WESTWOOD_CDP = "86380"
WHITE_CLOUD_CITY = "86680"
WHITE_PIGEON_VILLAGE = "86920"
WHITE_PINE_CDP = "86960"
WHITEHALL_CITY = "86780"
WHITMORE_LAKE_CDP = "87060"
WHITTEMORE_CITY = "87140"
WILLIAMSTON_CITY = "87420"
WINN_CDP = "87920"
WIXOM_CITY = "88140"
WOLF_LAKE_CDP = "88220"
WOLVERINE_LAKE_VILLAGE = "88260"
WOLVERINE_VILLAGE = "88240"
WOODHAVEN_CITY = "88380"
WOODLAND_BEACH_CDP = "88480"
WOODLAND_VILLAGE = "88420"
WYANDOTTE_CITY = "88900"
WYOMING_CITY = "88940"
YALE_CITY = "89000"
YPSILANTI_CITY = "89140"
ZEBA_CDP = "89240"
ZEELAND_CITY = "89260"
ZILWAUKEE_CITY = "89320"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in New York."""


ACCORD_CDP = "00155"
ADAMS_CENTER_CDP = "00232"
ADAMS_VILLAGE = "00199"
ADDISON_VILLAGE = "00276"
AFTON_VILLAGE = "00342"
AIRMONT_VILLAGE = "00408"
AKRON_VILLAGE = "00441"
AKWESASNE_CDP = "00457"
ALBANY_CITY = "01000"
ALBERTSON_CDP = "01011"
ALBION_VILLAGE = "01033"
ALDEN_VILLAGE = "01088"
ALEXANDER_VILLAGE = "01154"
ALEXANDRIA_BAY_VILLAGE = "01187"
ALFRED_VILLAGE = "01198"
ALLEGANY_VILLAGE = "01286"
ALMOND_VILLAGE = "01440"
ALTAMONT_VILLAGE = "01517"
ALTMAR_CDP = "01550"
ALTONA_CDP = "01572"
AMAGANSETT_CDP = "01594"
AMENIA_CDP = "01682"
AMES_VILLAGE = "01737"
AMITYVILLE_VILLAGE = "02044"
AMSTERDAM_CITY = "02066"
ANDES_CDP = "02121"
ANDOVER_VILLAGE = "02143"
ANGELICA_VILLAGE = "02176"
ANGOLA_ON_THE_LAKE_CDP = "02220"
ANGOLA_VILLAGE = "02198"
ANTWERP_VILLAGE = "02286"
APALACHIN_CDP = "02308"
AQUEBOGUE_CDP = "02374"
ARCADE_VILLAGE = "02407"
ARDSLEY_VILLAGE = "02506"
ARGYLE_VILLAGE = "02550"
ARKPORT_VILLAGE = "02583"
ARLINGTON_CDP = "02616"
ARMONK_CDP = "02649"
ASHAROKEN_VILLAGE = "02737"
ATHENS_VILLAGE = "02902"
ATLANTIC_BEACH_VILLAGE = "02968"
ATTICA_VILLAGE = "03001"
AU_SABLE_FORKS_CDP = "03254"
AUBURN_CITY = "03078"
AURORA_VILLAGE = "03188"
AVERILL_PARK_CDP = "03320"
AVOCA_VILLAGE = "03331"
AVON_VILLAGE = "03353"
BABYLON_VILLAGE = "03408"
BAINBRIDGE_VILLAGE = "04033"
BAITING_HOLLOW_CDP = "04055"
BALDWIN_CDP = "04143"
BALDWINSVILLE_VILLAGE = "04198"
BALLSTON_SPA_VILLAGE = "04253"
BALMVILLE_CDP = "04286"
BARD_COLLEGE_CDP = "04388"
BARDONIA_CDP = "04396"
BARKER_VILLAGE = "04440"
BARNEVELD_CDP = "04528"
BARNUM_ISLAND_CDP = "04550"
BARRYTOWN_CDP = "04605"
BARRYVILLE_CDP = "04616"
BATAVIA_CITY = "04715"
BATH_VILLAGE = "04759"
BAXTER_ESTATES_VILLAGE = "04803"
BAY_PARK_CDP = "04891"
BAY_SHORE_CDP = "04935"
BAYPORT_CDP = "04913"
BAYVILLE_VILLAGE = "05034"
BAYWOOD_CDP = "05039"
BEACON_CITY = "05100"
BEAVER_DAM_LAKE_CDP = "05188"
BEDFORD_CDP = "05309"
BEDFORD_HILLS_CDP = "05342"
BELFAST_CDP = "05562"
BELLE_TERRE_VILLAGE = "05672"
BELLEROSE_TERRACE_CDP = "05661"
BELLEROSE_VILLAGE = "05639"
BELLEVILLE_CDP = "05683"
BELLMORE_CDP = "05738"
BELLPORT_VILLAGE = "05771"
BELMONT_VILLAGE = "05815"
BEMUS_POINT_VILLAGE = "05848"
BERGEN_VILLAGE = "06046"
BETHPAGE_CDP = "06387"
BIG_FLATS_CDP = "06464"
BILLINGTON_HEIGHTS_CDP = "06574"
BINGHAMTON_UNIVERSITY_CDP = "06644"
BINGHAMTON_CITY = "06607"
BLACK_RIVER_VILLAGE = "06794"
BLASDELL_VILLAGE = "06849"
BLAUVELT_CDP = "06860"
BLISS_CDP = "06904"
BLODGETT_MILLS_CDP = "06937"
BLOOMFIELD_VILLAGE = "06945"
BLOOMINGBURG_VILLAGE = "06959"
BLOOMVILLE_CDP = "07025"
BLUE_POINT_CDP = "07069"
BOHEMIA_CDP = "07157"
BOLIVAR_VILLAGE = "07190"
BOLTON_LANDING_CDP = "07245"
BOONVILLE_VILLAGE = "07355"
BRASHER_FALLS_CDP = "07960"
BREESPORT_CDP = "08004"
BRENTWOOD_CDP = "08026"
BREWERTON_CDP = "08059"
BREWSTER_HEIGHTS_CDP = "08081"
BREWSTER_HILL_CDP = "08092"
BREWSTER_VILLAGE = "08070"
BRIARCLIFF_MANOR_VILLAGE = "08103"
BRIDGEHAMPTON_CDP = "08136"
BRIDGEPORT_CDP = "08147"
BRIDGEVILLE_CDP = "08158"
BRIDGEWATER_CDP = "08169"
BRIGHTON_CDP = "08257"
BRIGHTWATERS_VILLAGE = "08323"
BRINCKERHOFF_CDP = "08334"
BROADALBIN_VILLAGE = "08422"
BROCKPORT_VILLAGE = "08466"
BROCTON_VILLAGE = "08488"
BRONXVILLE_VILLAGE = "08532"
BROOKHAVEN_CDP = "09000"
BROOKTONDALE_CDP = "10077"
BROOKVILLE_VILLAGE = "10132"
BROWNVILLE_VILLAGE = "10231"
BRUSHTON_VILLAGE = "10286"
BUCHANAN_VILLAGE = "10341"
BUFFALO_CITY = "11000"
BURDETT_VILLAGE = "11132"
BURKE_VILLAGE = "11154"
BURLINGTON_FLATS_CDP = "11220"
BUSTI_CDP = "11440"
BYERSVILLE_CDP = "11550"
CADYVILLE_CDP = "11616"
CAIRO_CDP = "11638"
CALCIUM_CDP = "11671"
CALEDONIA_VILLAGE = "11704"
CALLICOON_CDP = "11748"
CALVERTON_CDP = "11781"
CAMBRIDGE_VILLAGE = "11825"
CAMDEN_VILLAGE = "11847"
CAMILLUS_VILLAGE = "11902"
CAMPBELL_CDP = "11935"
CANAJOHARIE_VILLAGE = "12111"
CANANDAIGUA_CITY = "12144"
CANASERAGA_VILLAGE = "12177"
CANASTOTA_VILLAGE = "12188"
CANDOR_VILLAGE = "12210"
CANISTEO_VILLAGE = "12254"
CANTON_VILLAGE = "12331"
CAPE_VINCENT_VILLAGE = "12353"
CAPTREE_CDP = "12402"
CARLE_PLACE_CDP = "12419"
CARMEL_CDP = "12518"
CAROGA_LAKE_CDP = "12584"
CARTHAGE_VILLAGE = "12683"
CASSADAGA_VILLAGE = "12749"
CASTILE_VILLAGE = "12771"
CASTLETON_ON_HUDSON_VILLAGE = "12870"
CASTORLAND_VILLAGE = "12881"
CATO_VILLAGE = "12958"
CATSKILL_VILLAGE = "13002"
CATTARAUGUS_VILLAGE = "13024"
CAYUGA_HEIGHTS_VILLAGE = "13079"
CAYUGA_VILLAGE = "13068"
CAZENOVIA_VILLAGE = "13145"
CEDARHURST_VILLAGE = "13233"
CELORON_VILLAGE = "13288"
CEMENTON_CDP = "13299"
CENTER_MORICHES_CDP = "13420"
CENTEREACH_CDP = "13376"
CENTERPORT_CDP = "13442"
CENTRAL_BRIDGE_CDP = "13530"
CENTRAL_ISLIP_CDP = "13552"
CENTRAL_SQUARE_VILLAGE = "13585"
CENTRE_ISLAND_VILLAGE = "13618"
CHADWICKS_CDP = "13662"
CHAMPLAIN_VILLAGE = "13739"
CHAPPAQUA_CDP = "13805"
CHATEAUGAY_VILLAGE = "13981"
CHATHAM_VILLAGE = "14003"
CHAUMONT_VILLAGE = "14036"
CHAUTAUQUA_CDP = "14058"
CHAZY_CDP = "14102"
CHEEKTOWAGA_CDP = "15000"
CHELSEA_COVE_CDP = "15060"
CHENANGO_BRIDGE_CDP = "15121"
CHERRY_CREEK_CDP = "15187"
CHERRY_VALLEY_VILLAGE = "15242"
CHESTER_VILLAGE = "15297"
CHESTERTOWN_CDP = "15363"
CHESTNUT_RIDGE_VILLAGE = "15400"
CHITTENANGO_VILLAGE = "15561"
CHURCHVILLE_VILLAGE = "15638"
CLARENCE_CDP = "15814"
CLARENCE_CENTER_CDP = "15836"
CLARK_MILLS_CDP = "15902"
CLARKSON_CDP = "15946"
CLAVERACK_RED_MILLS_CDP = "16050"
CLAYTON_VILLAGE = "16089"
CLAYVILLE_VILLAGE = "16111"
CLEVELAND_VILLAGE = "16188"
CLIFTON_GARDENS_CDP = "16298"
CLIFTON_KNOLLS_MILL_CREEK_CDP = "16322"
CLIFTON_SPRINGS_VILLAGE = "16375"
CLINTON_VILLAGE = "16419"
CLINTONDALE_CDP = "16452"
CLYDE_VILLAGE = "16573"
COBLESKILL_VILLAGE = "16628"
COHOCTON_VILLAGE = "16727"
COHOES_CITY = "16749"
COLD_BROOK_VILLAGE = "16815"
COLD_SPRING_HARBOR_CDP = "16958"
COLD_SPRING_VILLAGE = "16936"
COLONIE_VILLAGE = "17332"
COLTON_CDP = "17398"
COMMACK_CDP = "17530"
CONESUS_CDP = "17607"
CONESUS_LAKE_CDP = "17622"
CONGERS_CDP = "17739"
CONSTABLEVILLE_VILLAGE = "17882"
CONSTANTIA_CDP = "17893"
COOPERS_PLAINS_CDP = "18036"
COOPERSTOWN_VILLAGE = "18047"
COPAKE_CDP = "18091"
COPAKE_FALLS_CDP = "18113"
COPAKE_LAKE_CDP = "18124"
COPENHAGEN_VILLAGE = "18135"
COPIAGUE_CDP = "18146"
CORAM_CDP = "18157"
CORFU_VILLAGE = "18201"
CORINTH_VILLAGE = "18212"
CORNING_CITY = "18256"
CORNWALL_ON_HUDSON_VILLAGE = "18333"
CORTLAND_WEST_CDP = "18443"
CORTLAND_CITY = "18388"
COUNTRY_KNOLLS_CDP = "18542"
COVE_NECK_VILLAGE = "18597"
COXSACKIE_VILLAGE = "18718"
CRAGSMOOR_CDP = "18762"
CRANBERRY_LAKE_CDP = "18817"
CREST_VIEW_HEIGHTS_CDP = "18993"
CROGHAN_VILLAGE = "19070"
CROMPOND_CDP = "19092"
CROTON_ON_HUDSON_VILLAGE = "19213"
CROWN_HEIGHTS_CDP = "19229"
CRUGERS_CDP = "19290"
CRYSTAL_BEACH_CDP = "19308"
CUBA_VILLAGE = "19356"
CUMBERLAND_HEAD_CDP = "19408"
CUMMINSVILLE_CDP = "19411"
CUTCHOGUE_CDP = "19466"
CUYLERVILLE_CDP = "19510"
DALTON_CDP = "19587"
DANBY_CDP = "19609"
DANNEMORA_VILLAGE = "19642"
DANSVILLE_VILLAGE = "19664"
DAVENPORT_CENTER_CDP = "19774"
DE_WITT_CDP = "20467"
DEKALB_JUNCTION_CDP = "20049"
DERUYTER_VILLAGE = "20390"
DEER_PARK_CDP = "19972"
DEFERIET_VILLAGE = "19994"
DELANSON_VILLAGE = "20082"
DELEVAN_VILLAGE = "20115"
DELHI_VILLAGE = "20126"
DEPAUVILLE_CDP = "20302"
DEPEW_VILLAGE = "20313"
DEPOSIT_VILLAGE = "20346"
DERING_HARBOR_VILLAGE = "20379"
DEXTER_VILLAGE = "20500"
DIX_HILLS_CDP = "20687"
DOBBS_FERRY_VILLAGE = "20698"
DOLGEVILLE_VILLAGE = "20731"
DOVER_PLAINS_CDP = "20841"
DOWNSVILLE_CDP = "20852"
DRESDEN_VILLAGE = "20896"
DRYDEN_VILLAGE = "20951"
DUANE_LAKE_CDP = "20989"
DUANESBURG_CDP = "20995"
DUNDEE_VILLAGE = "21050"
DUNKIRK_CITY = "21105"
DURHAMVILLE_CDP = "21226"
EAGLE_BAY_CDP = "21380"
EARLVILLE_VILLAGE = "21523"
EAST_ATLANTIC_BEACH_CDP = "21578"
EAST_AURORA_VILLAGE = "21589"
EAST_AVON_CDP = "21600"
EAST_DURHAM_CDP = "21919"
EAST_FARMINGDALE_CDP = "21985"
EAST_FRANKFORT_CDP = "22029"
EAST_GLENVILLE_CDP = "22084"
EAST_GREENBUSH_CDP = "22106"
EAST_HAMPTON_NORTH_CDP = "22200"
EAST_HAMPTON_VILLAGE = "22183"
EAST_HERKIMER_CDP = "22238"
EAST_HILLS_VILLAGE = "22260"
EAST_ISLIP_CDP = "22315"
EAST_ITHACA_CDP = "22326"
EAST_KINGSTON_CDP = "22370"
EAST_MARION_CDP = "22447"
EAST_MASSAPEQUA_CDP = "22480"
EAST_MEADOW_CDP = "22502"
EAST_MORICHES_CDP = "22546"
EAST_NASSAU_VILLAGE = "22557"
EAST_NORTHPORT_CDP = "22612"
EAST_NORWICH_CDP = "22623"
EAST_PATCHOGUE_CDP = "22733"
EAST_QUOGUE_CDP = "22832"
EAST_RANDOLPH_CDP = "22843"
EAST_ROCHESTER_VILLAGE = "22865"
EAST_ROCKAWAY_VILLAGE = "22876"
EAST_SETAUKET_CDP = "22964"
EAST_SHOREHAM_CDP = "22980"
EAST_SYRACUSE_VILLAGE = "23052"
EAST_WILLISTON_VILLAGE = "23217"
EAST_WORCESTER_CDP = "23283"
EASTCHESTER_CDP = "21809"
EASTPORT_CDP = "22810"
EATONS_NECK_CDP = "23316"
EDEN_CDP = "23404"
EDMESTON_CDP = "23602"
EDWARDS_CDP = "23635"
EGGERTSVILLE_CDP = "23701"
ELBA_VILLAGE = "23745"
ELBRIDGE_VILLAGE = "23789"
ELDRED_CDP = "23811"
ELIZABETHTOWN_CDP = "23822"
ELLENVILLE_VILLAGE = "23965"
ELLICOTTVILLE_VILLAGE = "24020"
ELLISBURG_VILLAGE = "24075"
ELMA_CENTER_CDP = "24141"
ELMIRA_HEIGHTS_VILLAGE = "24251"
ELMIRA_CITY = "24229"
ELMONT_CDP = "24273"
ELMSFORD_VILLAGE = "24295"
ELWOOD_CDP = "24405"
ENDICOTT_VILLAGE = "24515"
ENDWELL_CDP = "24526"
ERIN_CDP = "24625"
ESPERANCE_VILLAGE = "24713"
EVANS_MILLS_VILLAGE = "24823"
FABIUS_VILLAGE = "24867"
FAIR_HAVEN_VILLAGE = "24988"
FAIRMOUNT_CDP = "25043"
FAIRPORT_VILLAGE = "25076"
FAIRVIEW_CDP_DUTCHESS_COUNTY = "25109"
FAIRVIEW_CDP_WESTCHESTER_COUNTY = "25120"
FALCONER_VILLAGE = "25164"
FALLSBURG_CDP = "25230"
FARMINGDALE_VILLAGE = "25384"
FARMINGVILLE_CDP = "25417"
FARNHAM_VILLAGE = "25428"
FAYETTEVILLE_VILLAGE = "25527"
FELTS_MILLS_CDP = "25571"
FILLMORE_CDP = "25747"
FIRE_ISLAND_CDP = "25839"
FIRTHCLIFFE_CDP = "25857"
FISHERS_ISLAND_CDP = "25923"
FISHERS_LANDING_CDP = "25934"
FISHKILL_VILLAGE = "25967"
FLANDERS_CDP = "26121"
FLEISCHMANNS_VILLAGE = "26209"
FLORAL_PARK_VILLAGE = "26264"
FLORIDA_VILLAGE = "26319"
FLOWER_HILL_VILLAGE = "26352"
FLY_CREEK_CDP = "26418"
FONDA_VILLAGE = "26462"
FOREST_HOME_CDP = "26561"
FORESTVILLE_CDP = "26649"
FORT_ANN_VILLAGE = "26704"
FORT_COVINGTON_CDP = "26726"
FORT_DRUM_CDP = "26759"
FORT_EDWARD_VILLAGE = "26770"
FORT_JOHNSON_VILLAGE = "26880"
FORT_MONTGOMERY_CDP = "26902"
FORT_PLAIN_VILLAGE = "26924"
FORT_SALONGA_CDP = "26946"
FOWLERVILLE_CDP = "27133"
FRANKFORT_VILLAGE = "27188"
FRANKLIN_SQUARE_CDP = "27309"
FRANKLIN_VILLAGE = "27221"
FRANKLINVILLE_VILLAGE = "27331"
FREDONIA_VILLAGE = "27419"
FREEDOM_PLAINS_CDP = "27452"
FREEPORT_VILLAGE = "27485"
FREEVILLE_VILLAGE = "27529"
FREWSBURG_CDP = "27672"
FRIENDSHIP_CDP = "27694"
FULTON_CITY = "27815"
FULTONVILLE_VILLAGE = "27859"
GAINESVILLE_VILLAGE = "27969"
GALEVILLE_CDP = "28035"
GALWAY_VILLAGE = "28101"
GANANDA_CDP = "28138"
GANG_MILLS_CDP = "28145"
GARDEN_CITY_PARK_CDP = "28189"
GARDEN_CITY_SOUTH_CDP = "28200"
GARDEN_CITY_VILLAGE = "28178"
GARDINER_CDP = "28244"
GARDNERTOWN_CDP = "28310"
GARRATTSVILLE_CDP = "28376"
GASPORT_CDP = "28431"
GATES_CDP = "28453"
GENESEO_VILLAGE = "28618"
GENEVA_CITY = "28640"
GERMANTOWN_CDP = "28761"
GHENT_CDP = "28860"
GILBERTSVILLE_VILLAGE = "28959"
GILGO_CDP = "28990"
GLASCO_CDP = "29014"
GLEN_AUBREY_CDP = "29058"
GLEN_COVE_CITY = "29113"
GLEN_HEAD_CDP = "29245"
GLEN_PARK_VILLAGE = "29322"
GLENS_FALLS_NORTH_CDP = "29338"
GLENS_FALLS_CITY = "29333"
GLENWOOD_LANDING_CDP = "29421"
GLOVERSVILLE_CITY = "29443"
GOLDENS_BRIDGE_CDP = "29476"
GORDON_HEIGHTS_CDP = "29509"
GORHAM_CDP = "29520"
GOSHEN_VILLAGE = "29542"
GOUVERNEUR_VILLAGE = "29597"
GOWANDA_VILLAGE = "29630"
GRAHAMSVILLE_CDP = "29707"
GRAND_VIEW_ON_HUDSON_VILLAGE = "29872"
GRANDYLE_VILLAGE_CDP = "29894"
GRANVILLE_VILLAGE = "30026"
GREAT_BEND_CDP = "30136"
GREAT_NECK_ESTATES_VILLAGE = "30191"
GREAT_NECK_GARDENS_CDP = "30202"
GREAT_NECK_PLAZA_VILLAGE = "30213"
GREAT_NECK_VILLAGE = "30169"
GREAT_RIVER_CDP = "30235"
GREECE_CDP = "30279"
GREEN_ISLAND_VILLAGE = "30521"
GREENE_VILLAGE = "30411"
GREENLAWN_CDP = "30543"
GREENPORT_WEST_CDP = "30581"
GREENPORT_VILLAGE = "30576"
GREENVALE_CDP = "30598"
GREENVILLE_CDP_GREENE_COUNTY = "30609"
GREENVILLE_CDP_WESTCHESTER_COUNTY = "30642"
GREENWICH_VILLAGE = "30675"
GREENWOOD_LAKE_VILLAGE = "30752"
GREIGSVILLE_CDP = "30807"
GROTON_VILLAGE = "30961"
GROVELAND_STATION_CDP = "31022"
GUILFORD_CDP = "31137"
HADLEY_CDP = "31258"
HAGAMAN_VILLAGE = "31291"
HAILESBORO_CDP = "31346"
HAINES_FALLS_CDP = "31357"
HALESITE_CDP = "31445"
HALL_CDP = "31533"
HAMBURG_VILLAGE = "31643"
HAMILTON_COLLEGE_CDP = "31746"
HAMILTON_VILLAGE = "31709"
HAMLIN_CDP = "31786"
HAMMOND_VILLAGE = "31830"
HAMMONDSPORT_VILLAGE = "31852"
HAMPTON_BAYS_CDP = "31896"
HAMPTON_MANOR_CDP = "31918"
HANCOCK_VILLAGE = "31940"
HANKINS_CDP = "31973"
HANNAWA_FALLS_CDP = "32006"
HANNIBAL_VILLAGE = "32017"
HARBOR_HILLS_CDP = "32094"
HARBOR_ISLE_CDP = "32105"
HARRIMAN_VILLAGE = "32325"
HARRIS_HILL_CDP = "32391"
HARRISON_VILLAGE = "32402"
HARTSDALE_CDP = "32523"
HARTWICK_CDP = "32578"
HARTWICK_SEMINARY_CDP = "32597"
HASTINGS_ON_HUDSON_VILLAGE = "32710"
HAUPPAUGE_CDP = "32732"
HAVERSTRAW_VILLAGE = "32754"
HAVILAND_CDP = "32776"
HAWTHORNE_CDP = "32842"
HEAD_OF_THE_HARBOR_VILLAGE = "32963"
HEMLOCK_CDP = "33128"
HEMPSTEAD_VILLAGE = "33139"
HENDERSON_CDP = "34044"
HERITAGE_HILLS_CDP = "34118"
HERKIMER_VILLAGE = "34121"
HERMON_CDP = "34165"
HERRICKS_CDP = "34198"
HERRINGS_CDP = "34220"
HEUVELTON_VILLAGE = "34264"
HEWLETT_BAY_PARK_VILLAGE = "34297"
HEWLETT_CDP = "34286"
HEWLETT_HARBOR_VILLAGE = "34308"
HEWLETT_NECK_VILLAGE = "34319"
HICKSVILLE_CDP = "34374"
HIGH_FALLS_CDP = "34451"
HIGHLAND_CDP = "34484"
HIGHLAND_FALLS_VILLAGE = "34495"
HIGHLAND_ON_THE_LAKE_CDP = "34528"
HILLBURN_VILLAGE = "34660"
HILLCREST_CDP = "34693"
HILLSIDE_CDP = "34786"
HILLSIDE_LAKE_CDP = "34803"
HILTON_VILLAGE = "34847"
HOBART_VILLAGE = "34979"
HOLBROOK_CDP = "35056"
HOLLAND_CDP = "35111"
HOLLAND_PATENT_VILLAGE = "35144"
HOLLEY_VILLAGE = "35155"
HOLTSVILLE_CDP = "35254"
HOMER_VILLAGE = "35276"
HONEOYE_CDP = "35353"
HONEOYE_FALLS_VILLAGE = "35364"
HOOSICK_FALLS_VILLAGE = "35474"
HOPEWELL_JUNCTION_CDP = "35573"
HORNELL_CITY = "35672"
HORSEHEADS_NORTH_CDP = "35710"
HORSEHEADS_VILLAGE = "35694"
HORTONVILLE_CDP = "35738"
HOUGHTON_CDP = "35771"
HUDSON_FALLS_VILLAGE = "35980"
HUDSON_CITY = "35969"
HUNT_CDP = "36156"
HUNTER_VILLAGE = "36167"
HUNTINGTON_BAY_VILLAGE = "37022"
HUNTINGTON_CDP = "36233"
HUNTINGTON_STATION_CDP = "37044"
HURLEY_CDP = "37132"
HURLEYVILLE_CDP = "37154"
HYDE_PARK_CDP = "37198"
ILION_VILLAGE = "37275"
INTERLAKEN_VILLAGE = "37528"
INWOOD_CDP = "37583"
IRONDEQUOIT_CDP = "37737"
IRVINGTON_VILLAGE = "37803"
ISLAND_PARK_VILLAGE = "37847"
ISLANDIA_VILLAGE = "37840"
ISLIP_CDP = "37869"
ISLIP_TERRACE_CDP = "38022"
ITHACA_CITY = "38077"
JACKSONVILLE_CDP = "38209"
JAMESPORT_CDP = "38253"
JAMESTOWN_WEST_CDP = "38275"
JAMESTOWN_CITY = "38264"
JEFFERSON_CDP = "38429"
JEFFERSON_HEIGHTS_CDP = "38451"
JEFFERSON_VALLEY_YORKTOWN_CDP = "38500"
JEFFERSONVILLE_VILLAGE = "38506"
JERICHO_CDP = "38539"
JOHNSON_CITY_VILLAGE = "38748"
JOHNSTOWN_CITY = "38781"
JORDAN_VILLAGE = "38825"
KASER_VILLAGE = "38934"
KATONAH_CDP = "38946"
KAUNEONGA_LAKE_CDP = "38985"
KEESEVILLE_CDP = "39089"
KENMORE_VILLAGE = "39232"
KENNEDY_CDP = "39243"
KENSINGTON_VILLAGE = "39309"
KERHONKSON_CDP = "39397"
KEUKA_PARK_CDP = "39463"
KIAMESHA_LAKE_CDP = "39485"
KINDERHOOK_VILLAGE = "39562"
KINGS_PARK_CDP = "39672"
KINGS_POINT_VILLAGE = "39694"
KINGSTON_CITY = "39727"
KIRYAS_JOEL_VILLAGE = "39853"
KYSORVILLE_CDP = "40175"
LA_FARGEVILLE_CDP = "40233"
LACKAWANNA_CITY = "40189"
LACONA_VILLAGE = "40200"
LAKE_CARMEL_CDP = "40398"
LAKE_DELTA_CDP = "40475"
LAKE_ERIE_BEACH_CDP = "40486"
LAKE_GEORGE_VILLAGE = "40508"
LAKE_GROVE_VILLAGE = "40530"
LAKE_HUNTINGTON_CDP = "40552"
LAKE_KATRINE_CDP = "40585"
LAKE_LUZERNE_CDP = "40651"
LAKE_MOHEGAN_CDP = "40689"
LAKE_PLACID_VILLAGE = "40761"
LAKE_RONKONKOMA_CDP = "40838"
LAKE_SUCCESS_VILLAGE = "40937"
LAKELAND_CDP = "40607"
LAKEVIEW_CDP = "41003"
LAKEVILLE_CDP = "41036"
LAKEWOOD_VILLAGE = "41069"
LANCASTER_VILLAGE = "41135"
LANSING_VILLAGE = "41223"
LARCHMONT_VILLAGE = "41333"
LATHAM_CDP = "41399"
LATTINGTOWN_VILLAGE = "41432"
LAUREL_CDP = "41465"
LAUREL_HOLLOW_VILLAGE = "41487"
LAURENS_VILLAGE = "41520"
LAWRENCE_VILLAGE = "41553"
LE_ROY_VILLAGE = "42026"
LEEDS_CDP = "41784"
LEICESTER_VILLAGE = "41872"
LEVITTOWN_CDP = "42081"
LEWISTON_VILLAGE = "42147"
LIBERTY_VILLAGE = "42224"
LIDO_BEACH_CDP = "42279"
LIMA_VILLAGE = "42323"
LIME_LAKE_CDP = "42345"
LIMESTONE_CDP = "42378"
LINCOLN_PARK_CDP = "42488"
LINCOLNDALE_CDP = "42455"
LINDENHURST_VILLAGE = "42554"
LINWOOD_CDP = "42609"
LISLE_VILLAGE = "42642"
LITTLE_FALLS_CITY = "42741"
LITTLE_VALLEY_VILLAGE = "42829"
LIVERPOOL_VILLAGE = "42884"
LIVINGSTON_MANOR_CDP = "42928"
LIVONIA_CENTER_CDP = "42972"
LIVONIA_VILLAGE = "42950"
LLOYD_HARBOR_VILLAGE = "43005"
LOCH_SHELDRAKE_CDP = "43038"
LOCKPORT_CITY = "43082"
LOCUST_VALLEY_CDP = "43192"
LODI_VILLAGE = "43214"
LONG_BEACH_CITY = "43335"
LONG_LAKE_CDP = "43401"
LORENZ_PARK_CDP = "43511"
LORRAINE_CDP = "43533"
LOUDONVILLE_CDP = "43566"
LOWVILLE_VILLAGE = "43720"
LYNBROOK_VILLAGE = "43874"
LYNCOURT_CDP = "43885"
LYNDONVILLE_VILLAGE = "43918"
LYON_MOUNTAIN_CDP = "43951"
LYONS_CDP = "43962"
LYONS_FALLS_VILLAGE = "44006"
MACDONNELL_HEIGHTS_CDP = "44105"
MACEDON_CDP = "44149"
MACHIAS_CDP = "44226"
MADISON_VILLAGE = "44424"
MADRID_CDP = "44479"
MAHOPAC_CDP = "44534"
MALDEN_ON_HUDSON_CDP = "44677"
MALONE_VILLAGE = "44710"
MALVERNE_PARK_OAKS_CDP = "44792"
MALVERNE_VILLAGE = "44787"
MAMARONECK_VILLAGE = "44831"
MANCHESTER_VILLAGE = "44853"
MANHASSET_CDP = "44897"
MANHASSET_HILLS_CDP = "44908"
MANLIUS_VILLAGE = "45018"
MANNSVILLE_VILLAGE = "45073"
MANORHAVEN_VILLAGE = "45106"
MANORVILLE_CDP = "45139"
MARATHON_VILLAGE = "45392"
MARCELLUS_VILLAGE = "45480"
MARCY_CDP = "45524"
MARGARETVILLE_VILLAGE = "45557"
MARIAVILLE_LAKE_CDP = "45573"
MARION_CDP = "45634"
MARIST_COLLEGE_CDP = "45659"
MARLBORO_CDP = "45700"
MASSAPEQUA_CDP = "45986"
MASSAPEQUA_PARK_VILLAGE = "45997"
MASSENA_VILLAGE = "46019"
MASTIC_BEACH_CDP = "46085"
MASTIC_CDP = "46074"
MATINECOCK_VILLAGE = "46107"
MATTITUCK_CDP = "46140"
MATTYDALE_CDP = "46151"
MAYBROOK_VILLAGE = "46162"
MAYFIELD_VILLAGE = "46206"
MAYVILLE_VILLAGE = "46239"
MCGRAW_VILLAGE = "44193"
MCLEAN_CDP = "44358"
MECHANICSTOWN_CDP = "46349"
MECHANICVILLE_CITY = "46360"
MEDFORD_CDP = "46404"
MEDINA_VILLAGE = "46415"
MELROSE_PARK_CDP = "46503"
MELVILLE_CDP = "46514"
MENANDS_VILLAGE = "46536"
MERIDIAN_VILLAGE = "46646"
MERRICK_CDP = "46668"
MERRITT_PARK_CDP = "46750"
MEXICO_VILLAGE = "46811"
MIDDLE_ISLAND_CDP = "46976"
MIDDLEBURGH_VILLAGE = "46866"
MIDDLEPORT_VILLAGE = "46998"
MIDDLETOWN_CITY = "47042"
MIDDLEVILLE_VILLAGE = "47108"
MILFORD_VILLAGE = "47229"
MILL_NECK_VILLAGE = "47405"
MILLBROOK_VILLAGE = "47273"
MILLER_PLACE_CDP = "47306"
MILLERTON_VILLAGE = "47361"
MILLPORT_VILLAGE = "47427"
MILLWOOD_CDP = "47482"
MILTON_CDP_SARATOGA_COUNTY = "47548"
MILTON_CDP_ULSTER_COUNTY = "47554"
MINEOLA_VILLAGE = "47636"
MINETTO_CDP = "47680"
MINEVILLE_CDP = "47702"
MINOA_VILLAGE = "47757"
MOHAWK_VILLAGE = "47823"
MONGAUP_VALLEY_CDP = "47977"
MONROE_VILLAGE = "47988"
MONSEY_CDP = "48010"
MONTAUK_CDP = "48054"
MONTEBELLO_VILLAGE = "48090"
MONTGOMERY_VILLAGE = "48142"
MONTICELLO_VILLAGE = "48175"
MONTOUR_FALLS_VILLAGE = "48197"
MONTROSE_CDP = "48208"
MOOERS_CDP = "48241"
MORAVIA_VILLAGE = "48296"
MORICHES_CDP = "48450"
MORRIS_VILLAGE = "48483"
MORRISONVILLE_CDP = "48538"
MORRISVILLE_VILLAGE = "48593"
MOUNT_IVY_CDP = "48879"
MOUNT_KISCO_VILLAGE = "48890"
MOUNT_MORRIS_VILLAGE = "48945"
MOUNT_SINAI_CDP = "49066"
MOUNT_VERNON_CITY = "49121"
MOUNT_VISION_CDP = "49143"
MOUNTAIN_DALE_CDP = "48736"
MOUNTAIN_LODGE_PARK_CDP = "48750"
MUNNSVILLE_VILLAGE = "49220"
MUNSEY_PARK_VILLAGE = "49231"
MUNSONS_CORNERS_CDP = "49242"
MUTTONTOWN_VILLAGE = "49330"
MYERS_CORNER_CDP = "49363"
NANUET_CDP = "49407"
NAPANOCH_CDP = "49418"
NAPEAGUE_CDP = "49424"
NAPLES_VILLAGE = "49429"
NARROWSBURG_CDP = "49473"
NASSAU_LAKE_CDP = "49555"
NASSAU_VILLAGE = "49506"
NATURAL_BRIDGE_CDP = "49605"
NAZARETH_COLLEGE_CDP = "49715"
NEDROW_CDP = "49726"
NELLISTON_VILLAGE = "49748"
NELSONVILLE_VILLAGE = "49781"
NESCONSET_CDP = "49825"
NEW_BALTIMORE_CDP = "49924"
NEW_BERLIN_VILLAGE = "49946"
NEW_CASSEL_CDP = "50067"
NEW_CITY_CDP = "50100"
NEW_HACKENSACK_CDP = "50265"
NEW_HAMBURG_CDP = "50276"
NEW_HARTFORD_VILLAGE = "50298"
NEW_HEMPSTEAD_VILLAGE = "50353"
NEW_HYDE_PARK_VILLAGE = "50397"
NEW_PALTZ_VILLAGE = "50551"
NEW_ROCHELLE_CITY = "50617"
NEW_SQUARE_VILLAGE = "50705"
NEW_SUFFOLK_CDP = "50727"
NEW_WINDSOR_CDP = "50837"
NEW_YORK_MILLS_VILLAGE = "51011"
NEW_YORK_CITY = "51000"
NEWARK_VALLEY_VILLAGE = "49902"
NEWARK_VILLAGE = "49891"
NEWBURGH_CITY = "50034"
NEWFANE_CDP = "50221"
NEWFIELD_CDP = "50243"
NEWPORT_VILLAGE = "50573"
NIAGARA_FALLS_CITY = "51055"
NIAGARA_UNIVERSITY_CDP = "51088"
NICHOLS_VILLAGE = "51110"
NISKAYUNA_CDP = "51262"
NISSEQUOGUE_VILLAGE = "51286"
NIVERVILLE_CDP = "51297"
NORFOLK_CDP = "51319"
NORTH_AMITYVILLE_CDP = "51396"
NORTH_BABYLON_CDP = "51440"
NORTH_BALLSTON_SPA_CDP = "51467"
NORTH_BAY_CDP = "51484"
NORTH_BAY_SHORE_CDP = "51495"
NORTH_BELLMORE_CDP = "51517"
NORTH_BELLPORT_CDP = "51528"
NORTH_BLENHEIM_CDP = "51561"
NORTH_BOSTON_CDP = "51583"
NORTH_COLLINS_VILLAGE = "51792"
NORTH_CREEK_CDP = "51847"
NORTH_GATES_CDP = "52040"
NORTH_GRANVILLE_CDP = "52067"
NORTH_GREAT_RIVER_CDP = "52078"
NORTH_HAVEN_VILLAGE = "52188"
NORTH_HILLS_VILLAGE = "53022"
NORTH_HORNELL_VILLAGE = "53055"
NORTH_LINDENHURST_CDP = "53198"
NORTH_LYNBROOK_CDP = "53231"
NORTH_MASSAPEQUA_CDP = "53253"
NORTH_MERRICK_CDP = "53264"
NORTH_NEW_HYDE_PARK_CDP = "53275"
NORTH_PATCHOGUE_CDP = "53319"
NORTH_ROSE_CDP = "53462"
NORTH_SEA_CDP = "53561"
NORTH_SYRACUSE_VILLAGE = "53660"
NORTH_TONAWANDA_CITY = "53682"
NORTH_VALLEY_STREAM_CDP = "53748"
NORTH_WANTAGH_CDP = "53792"
NORTHAMPTON_CDP = "51418"
NORTHEAST_ITHACA_CDP = "51915"
NORTHPORT_VILLAGE = "53396"
NORTHVILLE_CDP = "53775"
NORTHVILLE_VILLAGE = "53770"
NORTHWEST_HARBOR_CDP = "53852"
NORTHWEST_ITHACA_CDP = "53853"
NORWICH_CITY = "53979"
NORWOOD_VILLAGE = "54012"
NOYACK_CDP = "54056"
NUNDA_VILLAGE = "54078"
NYACK_VILLAGE = "54100"
OAK_BEACH_CDP = "54111"
OAKDALE_CDP = "54144"
OAKFIELD_VILLAGE = "54155"
OCEAN_BEACH_VILLAGE = "54430"
OCEANSIDE_CDP = "54441"
ODESSA_VILLAGE = "54452"
OGDENSBURG_CITY = "54485"
OLCOTT_CDP = "54540"
OLD_BETHPAGE_CDP = "54551"
OLD_BROOKVILLE_VILLAGE = "54562"
OLD_FIELD_VILLAGE = "54617"
OLD_FORGE_CDP = "54639"
OLD_WESTBURY_VILLAGE = "54705"
OLEAN_CITY = "54716"
ONEIDA_CASTLE_VILLAGE = "54848"
ONEIDA_CITY = "54837"
ONEONTA_CITY = "54881"
ONTARIO_CDP = "55002"
ORANGE_LAKE_CDP = "55189"
ORANGEBURG_CDP = "55167"
ORCHARD_PARK_VILLAGE = "55266"
ORIENT_CDP = "55321"
ORISKANY_FALLS_VILLAGE = "55376"
ORISKANY_VILLAGE = "55365"
OSSINING_VILLAGE = "55530"
OSWEGO_CITY = "55574"
OTEGO_VILLAGE = "55618"
OTISVILLE_VILLAGE = "55673"
OTTER_LAKE_CDP = "55750"
OVID_VILLAGE = "55816"
OWEGO_VILLAGE = "55882"
OXBOW_CDP = "55937"
OXFORD_VILLAGE = "55948"
OYSTER_BAY_CDP = "55992"
OYSTER_BAY_COVE_VILLAGE = "56011"
PAINTED_POST_VILLAGE = "56088"
PALATINE_BRIDGE_VILLAGE = "56110"
PALENVILLE_CDP = "56132"
PALMYRA_VILLAGE = "56187"
PAMELIA_CENTER_CDP = "56212"
PANAMA_VILLAGE = "56231"
PARC_CDP = "56291"
PARISH_VILLAGE = "56341"
PARISHVILLE_CDP = "56363"
PATCHOGUE_VILLAGE = "56660"
PAUL_SMITHS_CDP = "56770"
PAVILION_CDP = "56781"
PAWLING_VILLAGE = "56814"
PEACH_LAKE_CDP = "56869"
PEARL_RIVER_CDP = "56902"
PECONIC_CDP = "56968"
PEEKSKILL_CITY = "56979"
PELHAM_MANOR_VILLAGE = "57023"
PELHAM_VILLAGE = "57001"
PENN_YAN_VILLAGE = "57177"
PERRY_VILLAGE = "57243"
PERRYSBURG_CDP = "57287"
PERU_CDP = "57364"
PHELPS_VILLAGE = "57518"
PHILADELPHIA_VILLAGE = "57551"
PHILMONT_VILLAGE = "57639"
PHOENICIA_CDP = "57650"
PHOENIX_VILLAGE = "57661"
PIERMONT_VILLAGE = "57749"
PIERREPONT_MANOR_CDP = "57782"
PIFFARD_CDP = "57804"
PIKE_CDP = "57815"
PINE_BUSH_CDP = "57980"
PINE_HILL_CDP = "58057"
PINE_PLAINS_CDP = "58145"
PINE_VALLEY_CDP = "58189"
PITTSFORD_VILLAGE = "58354"
PLAINEDGE_CDP = "58409"
PLAINVIEW_CDP = "58442"
PLANDOME_HEIGHTS_VILLAGE = "58486"
PLANDOME_MANOR_VILLAGE = "58497"
PLANDOME_VILLAGE = "58475"
PLATTEKILL_CDP = "58541"
PLATTSBURGH_WEST_CDP = "58601"
PLATTSBURGH_CITY = "58574"
PLEASANT_VALLEY_CDP = "58684"
PLEASANTVILLE_VILLAGE = "58728"
PLESSIS_CDP = "58739"
POESTENKILL_CDP = "58794"
POINT_LOOKOUT_CDP = "58849"
POLAND_VILLAGE = "58937"
POMONA_VILLAGE = "58992"
POQUOTT_VILLAGE = "59157"
PORT_BYRON_VILLAGE = "59212"
PORT_CHESTER_VILLAGE = "59223"
PORT_DICKINSON_VILLAGE = "59245"
PORT_EWEN_CDP = "59311"
PORT_GIBSON_CDP = "59322"
PORT_HENRY_CDP = "59333"
PORT_JEFFERSON_STATION_CDP = "59377"
PORT_JEFFERSON_VILLAGE = "59355"
PORT_JERVIS_CITY = "59388"
PORT_LEYDEN_VILLAGE = "59454"
PORT_WASHINGTON_CDP = "59520"
PORT_WASHINGTON_NORTH_VILLAGE = "59531"
PORTLANDVILLE_CDP = "59443"
PORTVILLE_VILLAGE = "59498"
POTSDAM_VILLAGE = "59564"
POTTERSVILLE_CDP = "59619"
POUGHKEEPSIE_CITY = "59641"
PRATTSBURGH_CDP = "59708"
PRATTSVILLE_CDP = "59740"
PRESTON_POTTER_HOLLOW_CDP = "59831"
PROSPECT_CDP = "59883"
PULASKI_VILLAGE = "59960"
PULTNEYVILLE_CDP = "59993"
PUTNAM_LAKE_CDP = "60103"
QUIOGUE_CDP = "60408"
QUOGUE_VILLAGE = "60422"
RADISSON_CDP = "60455"
RANDOLPH_CDP = "60576"
RANSOMVILLE_CDP = "60598"
RAPIDS_CDP = "60609"
RAVENA_VILLAGE = "60675"
RED_CREEK_VILLAGE = "60829"
RED_HOOK_VILLAGE = "60895"
RED_OAKS_MILL_CDP = "60983"
REDFORD_CDP = "60884"
REDWOOD_CDP = "61016"
REMSEN_VILLAGE = "61115"
REMSENBURG_SPEONK_CDP = "61142"
RENSSELAER_FALLS_VILLAGE = "61159"
RENSSELAER_CITY = "61148"
RETSOF_CDP = "61236"
RHINEBECK_VILLAGE = "61346"
RHINECLIFF_CDP = "61368"
RICHBURG_VILLAGE = "61434"
RICHFIELD_SPRINGS_VILLAGE = "61489"
RICHMONDVILLE_VILLAGE = "61588"
RICHVILLE_VILLAGE = "61621"
RIDGE_CDP = "61665"
RIFTON_CDP = "61797"
RIPLEY_CDP = "61874"
RIVERHEAD_CDP = "61973"
RIVERSIDE_CDP = "62066"
RIVERSIDE_VILLAGE = "62061"
ROCHESTER_INSTITUTE_OF_TECHNOLOGY_CDP = "63014"
ROCHESTER_CITY = "63000"
ROCK_HILL_CDP = "63132"
ROCKVILLE_CENTRE_VILLAGE = "63264"
ROCKY_POINT_CDP = "63319"
RODMAN_CDP = "63330"
ROESSLEVILLE_CDP = "63363"
ROME_CITY = "63418"
ROMULUS_CDP = "63429"
RONKONKOMA_CDP = "63473"
ROOSEVELT_CDP = "63506"
ROSCOE_CDP = "63583"
ROSENDALE_CDP = "63725"
ROSLYN_ESTATES_VILLAGE = "63792"
ROSLYN_HARBOR_VILLAGE = "63803"
ROSLYN_HEIGHTS_CDP = "63814"
ROSLYN_VILLAGE = "63770"
ROTTERDAM_CDP = "63924"
ROUND_LAKE_VILLAGE = "63957"
ROUND_TOP_CDP = "63968"
ROUSES_POINT_VILLAGE = "63979"
RUBY_CDP = "64056"
RUSHFORD_CDP = "64155"
RUSHVILLE_VILLAGE = "64199"
RUSSELL_GARDENS_VILLAGE = "64232"
RYE_BROOK_VILLAGE = "64325"
RYE_CITY = "64309"
SUNY_OSWEGO_CDP = "72327"
SACKETS_HARBOR_VILLAGE = "64408"
SADDLE_ROCK_ESTATES_CDP = "64441"
SADDLE_ROCK_VILLAGE = "64430"
SAG_HARBOR_VILLAGE = "64485"
SAGAPONACK_VILLAGE = "64452"
SALAMANCA_CITY = "64749"
SALEM_CDP = "64771"
SALISBURY_CDP = "64842"
SALISBURY_CENTER_CDP = "64848"
SALISBURY_MILLS_CDP = "64859"
SALT_POINT_CDP = "64892"
SALTAIRE_VILLAGE = "64881"
SANBORN_CDP = "64958"
SAND_RIDGE_CDP = "65024"
SANDS_POINT_VILLAGE = "65035"
SANDY_CREEK_VILLAGE = "65068"
SARANAC_LAKE_VILLAGE = "65233"
SARATOGA_SPRINGS_CITY = "65255"
SAUGERTIES_SOUTH_CDP = "65310"
SAUGERTIES_VILLAGE = "65288"
SAVANNAH_CDP = "65332"
SAVONA_VILLAGE = "65354"
SAYVILLE_CDP = "65409"
SCARSDALE_VILLAGE = "65431"
SCHAGHTICOKE_VILLAGE = "65475"
SCHENECTADY_CITY = "65508"
SCHENEVUS_CDP = "65519"
SCHOHARIE_VILLAGE = "65585"
SCHROON_LAKE_CDP = "65640"
SCHUYLER_LAKE_CDP = "65739"
SCHUYLERVILLE_VILLAGE = "65750"
SCIO_CDP = "65761"
SCOTCHTOWN_CDP = "65882"
SCOTIA_VILLAGE = "65893"
SCOTTS_CORNERS_CDP = "65948"
SCOTTSBURG_CDP = "65926"
SCOTTSVILLE_VILLAGE = "65959"
SEA_CLIFF_VILLAGE = "66047"
SEAFORD_CDP = "66058"
SEARINGTOWN_CDP = "66102"
SELDEN_CDP = "66212"
SENECA_FALLS_CDP = "66322"
SENECA_KNOLLS_CDP = "66366"
SETAUKET_CDP = "66465"
SHARON_SPRINGS_VILLAGE = "66663"
SHELTER_ISLAND_CDP = "66828"
SHELTER_ISLAND_HEIGHTS_CDP = "66850"
SHENOROCK_CDP = "66872"
SHERBURNE_VILLAGE = "66883"
SHERMAN_VILLAGE = "66949"
SHERRILL_CITY = "66993"
SHINNECOCK_HILLS_CDP = "67048"
SHIRLEY_CDP = "67070"
SHOKAN_CDP = "67081"
SHOREHAM_VILLAGE = "67191"
SHOREHAVEN_CDP = "67207"
SHORTSVILLE_VILLAGE = "67257"
SHRUB_OAK_CDP = "67279"
SIDNEY_VILLAGE = "67334"
SIENA_COLLEGE_CDP = "67367"
SILVER_CREEK_VILLAGE = "67411"
SILVER_SPRINGS_VILLAGE = "67466"
SINCLAIRVILLE_VILLAGE = "67488"
SKANEATELES_VILLAGE = "67510"
SLATERVILLE_SPRINGS_CDP = "67631"
SLEEPY_HOLLOW_LAKE_CDP = "67640"
SLEEPY_HOLLOW_VILLAGE = "67638"
SLOAN_VILLAGE = "67686"
SLOATSBURG_VILLAGE = "67708"
SMALLWOOD_CDP = "67730"
SMITHTOWN_CDP = "67851"
SMITHVILLE_FLATS_CDP = "68088"
SMYRNA_VILLAGE = "68099"
SODUS_POINT_VILLAGE = "68242"
SODUS_VILLAGE = "68209"
SOLVAY_VILLAGE = "68286"
SOUND_BEACH_CDP = "68374"
SOUTH_BLOOMING_GROVE_VILLAGE = "68610"
SOUTH_CAIRO_CDP = "68737"
SOUTH_CORNING_VILLAGE = "68847"
SOUTH_DAYTON_VILLAGE = "68891"
SOUTH_EDMESTON_CDP = "68946"
SOUTH_FALLSBURG_CDP = "68968"
SOUTH_FARMINGDALE_CDP = "69001"
SOUTH_FLORAL_PARK_VILLAGE = "69023"
SOUTH_GLENS_FALLS_VILLAGE = "69078"
SOUTH_HEMPSTEAD_CDP = "69188"
SOUTH_HILL_CDP = "69199"
SOUTH_HUNTINGTON_CDP = "69254"
SOUTH_ILION_CDP = "69265"
SOUTH_LANSING_CDP = "69342"
SOUTH_LIMA_CDP = "69364"
SOUTH_LOCKPORT_CDP = "69386"
SOUTH_NYACK_VILLAGE = "69441"
SOUTH_VALLEY_STREAM_CDP = "69892"
SOUTHAMPTON_VILLAGE = "68462"
SOUTHOLD_CDP = "69452"
SOUTHPORT_CDP = "69606"
SPACKENKILL_CDP = "70035"
SPARKILL_CDP = "70068"
SPARROW_BUSH_CDP = "70090"
SPECULATOR_VILLAGE = "70123"
SPENCER_VILLAGE = "70167"
SPENCERPORT_VILLAGE = "70189"
SPRING_VALLEY_VILLAGE = "70420"
SPRINGFIELD_CENTER_CDP = "70321"
SPRINGS_CDP = "70387"
SPRINGVILLE_VILLAGE = "70442"
SPRINGWATER_CDP = "70464"
ST_BONAVENTURE_CDP = "64551"
ST_JAMES_CDP = "64584"
ST_JOHN_FISHER_COLLEGE_CDP = "64606"
ST_JOHNSVILLE_VILLAGE = "64639"
ST_REGIS_FALLS_CDP = "64716"
STAATSBURG_CDP = "70552"
STAMFORD_VILLAGE = "70618"
STANNARDS_CDP = "70717"
STAR_LAKE_CDP = "70849"
STEWART_MANOR_VILLAGE = "71267"
STILLWATER_VILLAGE = "71322"
STITTVILLE_CDP = "71377"
STONE_RIDGE_CDP = "71597"
STONY_BROOK_CDP = "71608"
STONY_BROOK_UNIVERSITY_CDP = "71620"
STONY_POINT_CDP = "71663"
STOTTVILLE_CDP = "71718"
STRYKERSVILLE_CDP = "71817"
SUFFERN_VILLAGE = "71894"
SUNSET_BAY_CDP = "72246"
SWAN_LAKE_CDP = "72400"
SYLVAN_BEACH_VILLAGE = "72521"
SYOSSET_CDP = "72554"
SYRACUSE_CITY = "73000"
TACONIC_SHORES_CDP = "73057"
TANNERSVILLE_VILLAGE = "73143"
TAPPAN_CDP = "73154"
TARRYTOWN_VILLAGE = "73176"
TERRYVILLE_CDP = "73352"
THENDARA_CDP = "73495"
THERESA_VILLAGE = "73517"
THIELLS_CDP = "73583"
THOMASTON_VILLAGE = "73605"
THORNWOOD_CDP = "73715"
THOUSAND_ISLAND_PARK_CDP = "73726"
THREE_MILE_BAY_CDP = "73737"
TICONDEROGA_CDP = "73880"
TILLSON_CDP = "73902"
TIOGA_TERRACE_CDP = "73990"
TITUSVILLE_CDP = "74017"
TIVOLI_VILLAGE = "74023"
TONAWANDA_TOWN_CDP = "75021"
TONAWANDA_CITY = "74166"
TOWN_LINE_CDP = "75121"
TRIBES_HILL_CDP = "75341"
TROY_CITY = "75484"
TRUMANSBURG_VILLAGE = "75506"
TUCKAHOE_CDP = "75572"
TUCKAHOE_VILLAGE = "75583"
TULLY_VILLAGE = "75627"
TUPPER_LAKE_VILLAGE = "75671"
TURIN_VILLAGE = "75682"
TUSCARORA_CDP = "75726"
TUXEDO_PARK_VILLAGE = "75803"
TUXEDO_VILLAGE = "75779"
UNADILLA_FORKS_CDP = "76023"
UNADILLA_VILLAGE = "76001"
UNION_SPRINGS_VILLAGE = "76155"
UNIONDALE_CDP = "76089"
UNIONVILLE_VILLAGE = "76210"
UNIVERSITY_GARDENS_CDP = "76287"
UNIVERSITY_AT_BUFFALO_CDP = "76280"
UPPER_BROOKVILLE_VILLAGE = "76331"
UPPER_NYACK_VILLAGE = "76386"
UPPER_RED_HOOK_CDP = "76397"
UTICA_CITY = "76540"
VAILS_GATE_CDP = "76584"
VALATIE_VILLAGE = "76617"
VALHALLA_CDP = "76639"
VALLEY_COTTAGE_CDP = "76661"
VALLEY_FALLS_VILLAGE = "76672"
VALLEY_STREAM_VILLAGE = "76705"
VAN_ETTEN_CDP = "76881"
VARNA_CDP = "76969"
VASSAR_COLLEGE_CDP = "76985"
VERNON_VILLAGE = "77112"
VERONA_CDP = "77167"
VERPLANCK_CDP = "77211"
VICTOR_VILLAGE = "77376"
VICTORY_VILLAGE = "77431"
VILLAGE_GREEN_CDP = "77513"
VILLAGE_OF_THE_BRANCH_VILLAGE = "77519"
VIOLA_CDP = "77574"
VIRGIL_CDP = "77585"
VOORHEESVILLE_VILLAGE = "77684"
WADDINGTON_VILLAGE = "77728"
WADING_RIVER_CDP = "77772"
WADSWORTH_CDP = "77783"
WAINSCOTT_CDP = "77805"
WALDEN_VILLAGE = "77849"
WALKER_VALLEY_CDP = "77948"
WALLKILL_CDP = "78003"
WALTON_PARK_CDP = "78063"
WALTON_VILLAGE = "78036"
WALWORTH_CDP = "78091"
WAMPSVILLE_VILLAGE = "78113"
WANAKAH_CDP = "78124"
WANTAGH_CDP = "78146"
WAPPINGERS_FALLS_VILLAGE = "78168"
WARRENSBURG_CDP = "78289"
WARSAW_VILLAGE = "78333"
WARWICK_VILLAGE = "78355"
WASHINGTON_HEIGHTS_CDP = "78421"
WASHINGTON_MILLS_CDP = "78454"
WASHINGTONVILLE_VILLAGE = "78465"
WASSAIC_CDP = "78476"
WATCHTOWER_CDP = "78487"
WATER_MILL_CDP = "78575"
WATERFORD_VILLAGE = "78520"
WATERLOO_VILLAGE = "78553"
WATERTOWN_CITY = "78608"
WATERVILLE_VILLAGE = "78663"
WATERVLIET_CITY = "78674"
WATKINS_GLEN_VILLAGE = "78696"
WAVERLY_VILLAGE = "78806"
WAYLAND_VILLAGE = "78850"
WEBSTER_VILLAGE = "78960"
WEBSTERS_CROSSING_CDP = "78982"
WEEDSPORT_VILLAGE = "79015"
WELLS_BRIDGE_CDP = "79070"
WELLS_CDP = "79048"
WELLSBURG_VILLAGE = "79081"
WELLSVILLE_VILLAGE = "79092"
WESLEY_HILLS_VILLAGE = "79174"
WEST_BABYLON_CDP = "79246"
WEST_BAY_SHORE_CDP = "79301"
WEST_CARTHAGE_VILLAGE = "79499"
WEST_CHAZY_CDP = "79543"
WEST_DANBY_CDP = "79697"
WEST_ELMIRA_CDP = "79785"
WEST_END_CDP = "79796"
WEST_GLENS_FALLS_CDP = "80082"
WEST_HAMPTON_DUNES_VILLAGE = "80186"
WEST_HAVERSTRAW_VILLAGE = "80203"
WEST_HEMPSTEAD_CDP = "80225"
WEST_HILLS_CDP = "80258"
WEST_HURLEY_CDP = "80291"
WEST_ISLIP_CDP = "80302"
WEST_KILL_CDP = "80324"
WEST_NYACK_CDP = "80599"
WEST_POINT_CDP = "80747"
WEST_SAND_LAKE_CDP = "80863"
WEST_SAYVILLE_CDP = "80885"
WEST_SENECA_CDP = "80907"
WEST_VALLEY_CDP = "81138"
WEST_WINFIELD_VILLAGE = "81292"
WESTBURY_VILLAGE = "79444"
WESTERNVILLE_CDP = "79895"
WESTFIELD_VILLAGE = "79939"
WESTFORD_CDP = "79961"
WESTHAMPTON_BEACH_VILLAGE = "80181"
WESTHAMPTON_CDP = "80170"
WESTMERE_CDP = "80423"
WESTMORELAND_CDP = "80522"
WESTON_MILLS_CDP = "80632"
WESTPORT_CDP = "80764"
WESTVALE_CDP = "81127"
WHEATLEY_HEIGHTS_CDP = "81419"
WHITE_LAKE_CDP_ONEIDA_COUNTY = "81644"
WHITE_LAKE_CDP_SULLIVAN_COUNTY = "81655"
WHITE_PLAINS_CITY = "81677"
WHITEHALL_VILLAGE = "81622"
WHITESBORO_VILLAGE = "81710"
WHITNEY_POINT_VILLAGE = "81831"
WILLIAMSON_CDP = "82029"
WILLIAMSVILLE_VILLAGE = "82084"
WILLISTON_PARK_VILLAGE = "82117"
WILLSBORO_CDP = "82260"
WILLSBORO_POINT_CDP = "82282"
WILMINGTON_CDP = "82304"
WILSON_VILLAGE = "82359"
WINDHAM_CDP = "82469"
WINDSOR_VILLAGE = "82524"
WINGDALE_CDP = "82579"
WINTHROP_CDP = "82612"
WITHERBEE_CDP = "82656"
WOLCOTT_VILLAGE = "82678"
WOODBOURNE_CDP = "82733"
WOODBURY_CDP = "82744"
WOODBURY_VILLAGE = "82750"
WOODMERE_CDP = "82942"
WOODRIDGE_VILLAGE = "82953"
WOODSBURGH_VILLAGE = "82986"
WOODSTOCK_CDP = "83041"
WOODSVILLE_CDP = "83063"
WORCESTER_CDP = "83118"
WURTSBORO_HILLS_CDP = "83283"
WURTSBORO_VILLAGE = "83272"
WYANDANCH_CDP = "83294"
WYNANTSKILL_CDP = "83349"
WYOMING_VILLAGE = "83371"
YAPHANK_CDP = "83426"
YONKERS_CITY = "84000"
YORK_CDP = "84011"
YORKSHIRE_CDP = "84044"
YORKTOWN_HEIGHTS_CDP = "84088"
YORKVILLE_VILLAGE = "84099"
YOUNGSTOWN_VILLAGE = "84143"
ZENA_CDP = "84187"



# Copyright (c) 2023 Darren Erik Vengroff
"""Counties in Georgia."""


APPLING = "001"
ATKINSON = "003"
BACON = "005"
BAKER = "007"
BALDWIN = "009"
BANKS = "011"
BARROW = "013"
BARTOW = "015"
BEN_HILL = "017"
BERRIEN = "019"
BIBB = "021"
BLECKLEY = "023"
BRANTLEY = "025"
BROOKS = "027"
BRYAN = "029"
BULLOCH = "031"
BURKE = "033"
BUTTS = "035"
CALHOUN = "037"
CAMDEN = "039"
CANDLER = "043"
CARROLL = "045"
CATOOSA = "047"
CHARLTON = "049"
CHATHAM = "051"
CHATTAHOOCHEE = "053"
CHATTOOGA = "055"
CHEROKEE = "057"
CLARKE = "059"
CLAY = "061"
CLAYTON = "063"
CLINCH = "065"
COBB = "067"
COFFEE = "069"
COLQUITT = "071"
COLUMBIA = "073"
COOK = "075"
COWETA = "077"
CRAWFORD = "079"
CRISP = "081"
DADE = "083"
DAWSON = "085"
DEKALB = "089"
DECATUR = "087"
DODGE = "091"
DOOLY = "093"
DOUGHERTY = "095"
DOUGLAS = "097"
EARLY = "099"
ECHOLS = "101"
EFFINGHAM = "103"
ELBERT = "105"
EMANUEL = "107"
EVANS = "109"
FANNIN = "111"
FAYETTE = "113"
FLOYD = "115"
FORSYTH = "117"
FRANKLIN = "119"
FULTON = "121"
GILMER = "123"
GLASCOCK = "125"
GLYNN = "127"
GORDON = "129"
GRADY = "131"
GREENE = "133"
GWINNETT = "135"
HABERSHAM = "137"
HALL = "139"
HANCOCK = "141"
HARALSON = "143"
HARRIS = "145"
HART = "147"
HEARD = "149"
HENRY = "151"
HOUSTON = "153"
IRWIN = "155"
JACKSON = "157"
JASPER = "159"
JEFF_DAVIS = "161"
JEFFERSON = "163"
JENKINS = "165"
JOHNSON = "167"
JONES = "169"
LAMAR = "171"
LANIER = "173"
LAURENS = "175"
LEE = "177"
LIBERTY = "179"
LINCOLN = "181"
LONG = "183"
LOWNDES = "185"
LUMPKIN = "187"
MACON = "193"
MADISON = "195"
MARION = "197"
MCDUFFIE = "189"
MCINTOSH = "191"
MERIWETHER = "199"
MILLER = "201"
MITCHELL = "205"
MONROE = "207"
MONTGOMERY = "209"
MORGAN = "211"
MURRAY = "213"
MUSCOGEE = "215"
NEWTON = "217"
OCONEE = "219"
OGLETHORPE = "221"
PAULDING = "223"
PEACH = "225"
PICKENS = "227"
PIERCE = "229"
PIKE = "231"
POLK = "233"
PULASKI = "235"
PUTNAM = "237"
QUITMAN = "239"
RABUN = "241"
RANDOLPH = "243"
RICHMOND = "245"
ROCKDALE = "247"
SCHLEY = "249"
SCREVEN = "251"
SEMINOLE = "253"
SPALDING = "255"
STEPHENS = "257"
STEWART = "259"
SUMTER = "261"
TALBOT = "263"
TALIAFERRO = "265"
TATTNALL = "267"
TAYLOR = "269"
TELFAIR = "271"
TERRELL = "273"
THOMAS = "275"
TIFT = "277"
TOOMBS = "279"
TOWNS = "281"
TREUTLEN = "283"
TROUP = "285"
TURNER = "287"
TWIGGS = "289"
UNION = "291"
UPSON = "293"
WALKER = "295"
WALTON = "297"
WARE = "299"
WARREN = "301"
WASHINGTON = "303"
WAYNE = "305"
WEBSTER = "307"
WHEELER = "309"
WHITE = "311"
WHITFIELD = "313"
WILCOX = "315"
WILKES = "317"
WILKINSON = "319"
WORTH = "321"



# Copyright (c) 2023 Darren Erik Vengroff
"""Places in Iowa."""


ACKLEY_CITY = "00190"
ACKWORTH_CITY = "00235"
ADAIR_CITY = "00370"
ADEL_CITY = "00505"
AFTON_CITY = "00595"
AGENCY_CITY = "00640"
AINSWORTH_CITY = "00730"
AKRON_CITY = "00775"
ALBERT_CITY_CITY = "00865"
ALBIA_CITY = "00910"
ALBION_CITY = "00955"
ALBURNETT_CITY = "01000"
ALDEN_CITY = "01045"
ALEXANDER_CITY = "01090"
ALGONA_CITY = "01135"
ALLEMAN_CITY = "01180"
ALLERTON_CITY = "01270"
ALLISON_CITY = "01315"
ALTA_VISTA_CITY = "01540"
ALTA_CITY = "01495"
ALTON_CITY = "01585"
ALTOONA_CITY = "01630"
ALVORD_CITY = "01675"
AMANA_CDP = "01720"
AMES_CITY = "01855"
ANAMOSA_CITY = "01990"
ANDERSON_CDP = "02035"
ANDOVER_CITY = "02080"
ANDREW_CITY = "02125"
ANITA_CITY = "02260"
ANKENY_CITY = "02305"
ANTHON_CITY = "02350"
APLINGTON_CITY = "02395"
ARCADIA_CITY = "02485"
ARCHER_CITY = "02530"
AREDALE_CITY = "02620"
ARGO_CDP = "02665"
ARGYLE_CDP = "02710"
ARION_CITY = "02755"
ARISPE_CITY = "02800"
ARLINGTON_CITY = "02845"
ARMSTRONG_CITY = "02935"
ARNOLDS_PARK_CITY = "03025"
ARTHUR_CITY = "03115"
ASBURY_CITY = "03160"
ASHTON_CITY = "03295"
ASPINWALL_CITY = "03340"
ATALISSA_CITY = "03385"
ATHELSTAN_CDP = "03430"
ATKINS_CITY = "03475"
ATLANTIC_CITY = "03520"
AUBURN_CITY = "03610"
AUDUBON_CITY = "03655"
AUGUSTA_CDP = "03700"
AURELIA_CITY = "03745"
AURORA_CITY = "03835"
AVOCA_CITY = "03970"
AYRSHIRE_CITY = "04105"
BADGER_CITY = "04195"
BAGLEY_CITY = "04240"
BALDWIN_CITY = "04330"
BALLTOWN_CITY = "04375"
BANCROFT_CITY = "04420"
BANKSTON_CITY = "04510"
BARNES_CITY_CITY = "04555"
BARNUM_CITY = "04645"
BARTLETT_CDP = "04735"
BASSETT_CITY = "04780"
BATAVIA_CITY = "04825"
BATTLE_CREEK_CITY = "04870"
BAXTER_CITY = "04915"
BAYARD_CITY = "04960"
BEACON_CITY = "05050"
BEACONSFIELD_CITY = "05095"
BEAMAN_CITY = "05140"
BEAVER_CITY = "05185"
BEAVERDALE_CDP = "05200"
BEDFORD_CITY = "05365"
BELLE_PLAINE_CITY = "05590"
BELLEVUE_CITY = "05635"
BELMOND_CITY = "05680"
BENNETT_CITY = "05770"
BENTLEY_CDP = "05870"
BENTON_CITY = "05905"
BERKLEY_CITY = "06040"
BERNARD_CITY = "06085"
BERTRAM_CITY = "06175"
BETTENDORF_CITY = "06355"
BEVINGTON_CITY = "06490"
BIG_ROCK_CDP = "06535"
BIRMINGHAM_CITY = "06625"
BLAIRSBURG_CITY = "06760"
BLAIRSTOWN_CITY = "06805"
BLAKESBURG_CITY = "06850"
BLANCHARD_CITY = "06895"
BLENCOE_CITY = "06940"
BLOCKTON_CITY = "06985"
BLOOMFIELD_CITY = "07030"
BLUE_GRASS_CITY = "07075"
BODE_CITY = "07210"
BOLAN_CDP = "07255"
BONAPARTE_CITY = "07345"
BONDURANT_CITY = "07390"
BOONE_CITY = "07480"
BOUTON_CITY = "07660"
BOXHOLM_CITY = "07750"
BOYDEN_CITY = "07840"
BRADDYVILLE_CITY = "07930"
BRADFORD_CDP = "08020"
BRADGATE_CITY = "08065"
BRANDON_CITY = "08155"
BRAYTON_CITY = "08200"
BREDA_CITY = "08290"
BRIDGEWATER_CITY = "08425"
BRIGHTON_CITY = "08470"
BRISTOW_CITY = "08560"
BRITT_CITY = "08605"
BRONSON_CITY = "08650"
BROOKLYN_CITY = "08695"
BRUNSVILLE_CITY = "08875"
BUCK_GROVE_CITY = "09145"
BUCKEYE_CITY = "09100"
BUFFALO_CENTER_CITY = "09280"
BUFFALO_CITY = "09235"
BURCHINAL_CDP = "09415"
BURLINGTON_CITY = "09550"
BURR_OAK_CDP = "09640"
BURT_CITY = "09685"
BUSSEY_CITY = "09730"
CALAMUS_CITY = "09820"
CALIFORNIA_JUNCTION_CDP = "09910"
CALLENDER_CITY = "09955"
CALMAR_CITY = "10045"
CALUMET_CITY = "10090"
CAMANCHE_CITY = "10135"
CAMBRIDGE_CITY = "10225"
CANTRIL_CITY = "10450"
CARBON_CITY = "10585"
CARLISLE_CITY = "10765"
CARPENTER_CITY = "11035"
CARROLL_CITY = "11080"
CARSON_CITY = "11170"
CARTER_LAKE_CITY = "11215"
CASCADE_CITY = "11305"
CASEY_CITY = "11395"
CASTALIA_CITY = "11485"
CASTANA_CITY = "11530"
CEDAR_FALLS_CITY = "11755"
CEDAR_RAPIDS_CITY = "12000"
CENTER_JUNCTION_CDP = "12225"
CENTER_POINT_CITY = "12270"
CENTERVILLE_CITY = "12315"
CENTRAL_CITY_CITY = "12495"
CENTRALIA_CITY = "12630"
CHAPIN_CDP = "12675"
CHARITON_CITY = "12720"
CHARLES_CITY_CITY = "12765"
CHARLOTTE_CITY = "12855"
CHARTER_OAK_CITY = "12900"
CHATSWORTH_CITY = "12945"
CHELSEA_CITY = "12990"
CHEROKEE_CITY = "13080"
CHESTER_CITY = "13125"
CHILLICOTHE_CITY = "13215"
CHURDAN_CITY = "13350"
CINCINNATI_CITY = "13395"
CLARE_CITY = "13485"
CLARENCE_CITY = "13530"
CLARINDA_CITY = "13575"
CLARION_CITY = "13620"
CLARKSVILLE_CITY = "13755"
CLAYTON_CITY = "13845"
CLEAR_LAKE_CITY = "14025"
CLEARFIELD_CITY = "13980"
CLEGHORN_CITY = "14115"
CLEMONS_CITY = "14160"
CLERMONT_CITY = "14250"
CLIMBING_HILL_CDP = "14385"
CLINTON_CITY = "14430"
CLIO_CITY = "14475"
CLIVE_CITY = "14520"
CLUTIER_CITY = "14655"
COALVILLE_CDP = "14835"
COBURG_CITY = "14880"
COGGON_CITY = "14925"
COIN_CITY = "14970"
COLESBURG_CITY = "15015"
COLFAX_CITY = "15060"
COLLEGE_SPRINGS_CITY = "15105"
COLLINS_CITY = "15195"
COLO_CITY = "15240"
COLUMBUS_CITY_CITY = "15375"
COLUMBUS_JUNCTION_CITY = "15420"
COLWELL_CITY = "15465"
CONESVILLE_CITY = "15645"
CONRAD_CITY = "15825"
CONROY_CDP = "15870"
CONWAY_CITY = "15960"
COON_RAPIDS_CITY = "16050"
COPPOCK_CITY = "16140"
CORALVILLE_CITY = "16230"
CORLEY_CDP = "16320"
CORNING_CITY = "16500"
CORRECTIONVILLE_CITY = "16545"
CORWITH_CITY = "16590"
CORYDON_CITY = "16635"
COTTER_CITY = "16725"
COULTER_CITY = "16815"
COUNCIL_BLUFFS_CITY = "16860"
CRAIG_CITY = "16950"
CRAWFORDSVILLE_CITY = "17130"
CRESCENT_CITY = "17175"
CRESCO_CITY = "17220"
CRESTON_CITY = "17265"
CROMWELL_CITY = "17490"
CRYSTAL_LAKE_CITY = "17670"
CUMBERLAND_CITY = "17760"
CUMMING_CITY = "17850"
CURLEW_CITY = "17895"
CUSHING_CITY = "17940"
CYLINDER_CITY = "17985"
DAKOTA_CITY_CITY = "18075"
DALLAS_CENTER_CITY = "18255"
DANA_CITY = "18345"
DANBURY_CITY = "18390"
DANVILLE_CITY = "18435"
DAVENPORT_CITY = "19000"
DAVIS_CITY_CITY = "19090"
DAWSON_CITY = "19135"
DAYTON_CITY = "19180"
DE_SOTO_CITY = "21045"
DEWITT_CITY = "21180"
DECATUR_CITY_CITY = "19360"
DECORAH_CITY = "19405"
DEDHAM_CITY = "19450"
DEEP_RIVER_CITY = "19495"
DEFIANCE_CITY = "19585"
DELAWARE_CITY = "19630"
DELHI_CITY = "19675"
DELMAR_CITY = "19720"
DELOIT_CITY = "19765"
DELPHOS_CDP = "19810"
DELTA_CITY = "19855"
DENISON_CITY = "19945"
DENMARK_CDP = "19990"
DENVER_CITY = "20035"
DERBY_CITY = "20125"
DES_MOINES_CITY = "21000"
DEXTER_CITY = "21225"
DIAGONAL_CITY = "21270"
DIAMONDHEAD_LAKE_CDP = "21320"
DICKENS_CITY = "21360"
DIKE_CITY = "21405"
DIXON_CITY = "21540"
DOLLIVER_CITY = "21675"
DONAHUE_CITY = "21720"
DONNELLSON_CITY = "21810"
DOON_CITY = "21900"
DOUDS_CDP = "22035"
DOUGHERTY_CITY = "22080"
DOW_CITY_CITY = "22215"
DOWNEY_CDP = "22260"
DOWS_CITY = "22305"
DRAKESVILLE_CITY = "22350"
DUBUQUE_CITY = "22395"
DUMONT_CITY = "22620"
DUNCAN_CDP = "22710"
DUNCOMBE_CITY = "22755"
DUNDEE_CITY = "22800"
DUNKERTON_CITY = "22845"
DUNLAP_CITY = "22890"
DURANGO_CITY = "22935"
DURANT_CITY = "22980"
DYERSVILLE_CITY = "23115"
DYSART_CITY = "23160"
EAGLE_GROVE_CITY = "23250"
EARLHAM_CITY = "23340"
EARLING_CITY = "23385"
EARLVILLE_CITY = "23430"
EARLY_CITY = "23475"
EAST_AMANA_CDP = "23520"
EAST_PERU_CITY = "23790"
EDDYVILLE_CITY = "23970"
EDGEWOOD_CITY = "24060"
ELBERON_CITY = "24375"
ELDON_CITY = "24420"
ELDORA_CITY = "24465"
ELDRIDGE_CITY = "24600"
ELGIN_CITY = "24645"
ELK_HORN_CITY = "24780"
ELK_RUN_HEIGHTS_CITY = "24870"
ELKADER_CITY = "24690"
ELKHART_CITY = "24735"
ELKPORT_CITY = "24825"
ELLIOTT_CITY = "24915"
ELLSTON_CITY = "25005"
ELLSWORTH_CITY = "25050"
ELMA_CITY = "25095"
ELY_CITY = "25365"
EMERSON_CITY = "25500"
EMMETSBURG_CITY = "25590"
EPWORTH_CITY = "25725"
ESSEX_CITY = "25815"
ESTHERVILLE_CITY = "25860"
EVANSDALE_CITY = "25995"
EVERLY_CITY = "26175"
EXIRA_CITY = "26265"
EXLINE_CITY = "26310"
FAIRBANK_CITY = "26355"
FAIRFAX_CITY = "26400"
FAIRFIELD_CITY = "26445"
FAIRPORT_CDP = "26580"
FARLEY_CITY = "26760"
FARMERSBURG_CITY = "26850"
FARMINGTON_CITY = "26895"
FARNHAMVILLE_CITY = "26940"
FARRAGUT_CITY = "26985"
FAYETTE_CITY = "27165"
FENTON_CITY = "27210"
FERGUSON_CITY = "27255"
FERTILE_CITY = "27390"
FLORIS_CITY = "27975"
FLOYD_CITY = "28020"
FONDA_CITY = "28245"
FONTANELLE_CITY = "28290"
FOREST_CITY_CITY = "28380"
FORT_ATKINSON_CITY = "28425"
FORT_DODGE_CITY = "28515"
FORT_MADISON_CITY = "28605"
FOSTORIA_CITY = "28650"
FRANKLIN_CITY = "28740"
FRASER_CITY = "28920"
FREDERICKSBURG_CITY = "28965"
FREDERIKA_CITY = "29010"
FREDONIA_CITY = "29055"
FREMONT_CITY = "29190"
FRUITLAND_CITY = "29280"
FRYTOWN_CDP = "29325"
GALT_CITY = "29550"
GALVA_CITY = "29595"
GARBER_CITY = "29685"
GARDEN_CITY_CDP = "29730"
GARDEN_GROVE_CITY = "29775"
GARNAVILLO_CITY = "29910"
GARNER_CITY = "29955"
GARRISON_CITY = "30000"
GARWIN_CITY = "30045"
GENEVA_CITY = "30135"
GEORGE_CITY = "30225"
GIBSON_CITY = "30540"
GILBERT_CITY = "30630"
GILBERTVILLE_CITY = "30675"
GILLETT_GROVE_CITY = "30810"
GILMAN_CITY = "30900"
GILMORE_CITY_CITY = "30945"
GLADBROOK_CITY = "31035"
GLENWOOD_CITY = "31350"
GLIDDEN_CITY = "31395"
GOLDFIELD_CITY = "31530"
GOODELL_CITY = "31575"
GOOSE_LAKE_CITY = "31665"
GOWRIE_CITY = "31710"
GRAETTINGER_CITY = "31800"
GRAF_CITY = "31845"
GRAFTON_CITY = "31890"
GRAND_JUNCTION_CITY = "31980"
GRAND_MOUND_CITY = "32025"
GRAND_RIVER_CITY = "32070"
GRANDVIEW_CITY = "32115"
GRANGER_CITY = "32160"
GRANT_CITY = "32295"
GRANVILLE_CITY = "32475"
GRAVITY_CITY = "32520"
GRAY_CITY = "32565"
GREELEY_CITY = "32610"
GREEN_MOUNTAIN_CDP = "32925"
GREENE_CITY = "32745"
GREENFIELD_CITY = "32790"
GREENVILLE_CITY = "32970"
GRIMES_CITY = "33060"
GRINNELL_CITY = "33105"
GRISWOLD_CITY = "33150"
GRUNDY_CENTER_CITY = "33195"
GRUVER_CITY = "33240"
GUERNSEY_CITY = "33285"
GUTHRIE_CENTER_CITY = "33420"
GUTTENBERG_CITY = "33465"
HALBUR_CITY = "33645"
HAMBURG_CITY = "33780"
HAMILTON_CITY = "33870"
HAMPTON_CITY = "33960"
HANCOCK_CITY = "34005"
HANLONTOWN_CITY = "34185"
HANSELL_CITY = "34365"
HARCOURT_CITY = "34410"
HARDY_CITY = "34455"
HARLAN_CITY = "34500"
HARPER_CITY = "34545"
HARPERS_FERRY_CITY = "34590"
HARRIS_CITY = "34635"
HARTFORD_CITY = "34680"
HARTLEY_CITY = "34725"
HARTWICK_CITY = "34770"
HARVEY_CITY = "34860"
HASTINGS_CITY = "34995"
HAVELOCK_CITY = "35130"
HAVERHILL_CITY = "35220"
HAWARDEN_CITY = "35265"
HAWKEYE_CITY = "35310"
HAYESVILLE_CITY = "35445"
HAYFIELD_CDP = "35490"
HAZLETON_CITY = "35580"
HEDRICK_CITY = "35670"
HENDERSON_CITY = "35715"
HEPBURN_CITY = "35760"
HIAWATHA_CITY = "35940"
HIGH_AMANA_CDP = "36030"
HILLS_CITY = "36345"
HILLSBORO_CITY = "36390"
HINTON_CITY = "36480"
HOLIDAY_LAKE_CDP = "36660"
HOLLAND_CITY = "36705"
HOLSTEIN_CITY = "36840"
HOLY_CROSS_CITY = "36885"
HOMESTEAD_CDP = "36975"
HOPKINTON_CITY = "37155"
HORNICK_CITY = "37200"
HOSPERS_CITY = "37290"
HOUGHTON_CITY = "37335"
HUBBARD_CITY = "37425"
HUDSON_CITY = "37470"
HULL_CITY = "37515"
HUMBOLDT_CITY = "37560"
HUMESTON_CITY = "37605"
HUTCHINS_CDP = "37875"
HUXLEY_CITY = "37920"
IDA_GROVE_CITY = "38010"
IMOGENE_CITY = "38055"
INDEPENDENCE_CITY = "38100"
INDIANOLA_CITY = "38280"
INWOOD_CITY = "38415"
IONIA_CITY = "38460"
IOWA_CITY_CITY = "38595"
IOWA_FALLS_CITY = "38640"
IRETON_CITY = "38820"
IRVINGTON_CDP = "38955"
IRWIN_CITY = "39000"
JACKSON_JUNCTION_CITY = "39135"
JACKSONVILLE_CDP = "39180"
JAMAICA_CITY = "39225"
JANESVILLE_CITY = "39405"
JEFFERSON_CITY = "39450"
JESUP_CITY = "39585"
JEWELL_JUNCTION_CITY = "39675"
JOHNSTON_CITY = "39765"
JOICE_CITY = "39855"
JOLLEY_CITY = "39900"
KALONA_CITY = "40170"
KAMRAR_CITY = "40215"
KANAWHA_CITY = "40260"
KELLERTON_CITY = "40350"
KELLEY_CITY = "40395"
KELLOGG_CITY = "40440"
KENSETT_CITY = "40665"
KENT_CDP = "40710"
KENT_ESTATES_CDP = "40733"
KEOKUK_CITY = "40845"
KEOMAH_VILLAGE_CITY = "40890"
KEOSAUQUA_CITY = "40935"
KEOTA_CITY = "40980"
KESWICK_CITY = "41070"
KEYSTONE_CITY = "41115"
KIMBALLTON_CITY = "41295"
KINGSLEY_CITY = "41385"
KINGSTON_CDP = "41430"
KINROSS_CITY = "41475"
KIRKMAN_CITY = "41520"
KIRKVILLE_CITY = "41565"
KIRON_CITY = "41610"
KLEMME_CITY = "41655"
KNIERIM_CITY = "41790"
KNOXVILLE_CITY = "42015"
LA_MOTTE_CITY = "43050"
LA_PORTE_CITY_CITY = "43365"
LACONA_CITY = "42285"
LADORA_CITY = "42330"
LAKE_CITY_CITY = "42465"
LAKE_MILLS_CITY = "42555"
LAKE_PANORAMA_CDP = "42575"
LAKE_PARK_CITY = "42600"
LAKE_VIEW_CITY = "42690"
LAKESIDE_CITY = "42645"
LAKOTA_CITY = "42825"
LAMBS_GROVE_CITY = "42870"
LAMONI_CITY = "42960"
LAMONT_CITY = "43005"
LANESBORO_CITY = "43140"
LANSING_CITY = "43275"
LARCHWOOD_CITY = "43410"
LARRABEE_CITY = "43500"
LATIMER_CITY = "43590"
LAUREL_CITY = "43680"
LAURENS_CITY = "43725"
LAWLER_CITY = "43815"
LAWTON_CITY = "43905"
LE_CLAIRE_CITY = "44085"
LE_GRAND_CITY = "44220"
LE_MARS_CITY = "44400"
LE_ROY_CITY = "44580"
LEANDO_CDP = "43950"
LEDYARD_CITY = "44130"
LEHIGH_CITY = "44265"
LEIGHTON_CITY = "44310"
LELAND_CITY = "44355"
LENOX_CITY = "44490"
LEON_CITY = "44535"
LESTER_CITY = "44670"
LETTS_CITY = "44715"
LEWIS_CITY = "44805"
LIBERTYVILLE_CITY = "44985"
LIDDERDALE_CITY = "45030"
LIME_SPRINGS_CITY = "45165"
LINCOLN_CITY = "45255"
LINDEN_CITY = "45390"
LINEVILLE_CITY = "45435"
LINN_GROVE_CITY = "45480"
LISBON_CITY = "45615"
LISCOMB_CITY = "45660"
LITTLE_CEDAR_CDP = "45705"
LITTLE_ROCK_CITY = "45795"
LITTLE_SIOUX_CITY = "45840"
LIVERMORE_CITY = "45975"
LOCKRIDGE_CITY = "46065"
LOGAN_CITY = "46155"
LOHRVILLE_CITY = "46245"
LONE_ROCK_CITY = "46290"
LONE_TREE_CITY = "46335"
LONG_GROVE_CITY = "46425"
LORIMOR_CITY = "46515"
LOST_NATION_CITY = "46605"
LOVELAND_CDP = "46785"
LOVILIA_CITY = "46830"
LOW_MOOR_CITY = "47010"
LOWDEN_CITY = "46920"
LOWELL_CDP = "46965"
LU_VERNE_CITY = "47370"
LUANA_CITY = "47055"
LUCAS_CITY = "47100"
LUTHER_CITY = "47280"
LUXEMBURG_CITY = "47460"
LUZERNE_CITY = "47505"
LYNNVILLE_CITY = "47595"
LYTTON_CITY = "47730"
MACEDONIA_CITY = "47955"
MACKSBURG_CITY = "48180"
MADRID_CITY = "48450"
MAGNOLIA_CITY = "48495"
MAHARISHI_VEDIC_CITY_CITY = "48500"
MALCOM_CITY = "48540"
MALLARD_CITY = "48585"
MALOY_CITY = "48675"
MALVERN_CITY = "48720"
MANCHESTER_CITY = "48810"
MANILLA_CITY = "48855"
MANLY_CITY = "48900"
MANNING_CITY = "48945"
MANSON_CITY = "48990"
MAPLETON_CITY = "49170"
MAQUOKETA_CITY = "49215"
MARATHON_CITY = "49260"
MARBLE_ROCK_CITY = "49305"
MARCUS_CITY = "49350"
MARENGO_CITY = "49395"
MARION_CITY = "49485"
MARNE_CITY = "49575"
MARQUETTE_CITY = "49620"
MARSHALLTOWN_CITY = "49755"
MARTELLE_CITY = "49845"
MARTENSDALE_CITY = "49890"
MARTINSBURG_CITY = "49935"
MARYSVILLE_CITY = "50070"
MASON_CITY_CITY = "50160"
MASONVILLE_CITY = "50205"
MASSENA_CITY = "50250"
MATLOCK_CITY = "50385"
MAURICE_CITY = "50430"
MAXWELL_CITY = "50520"
MAYNARD_CITY = "50610"
MAYSVILLE_CITY = "50655"
MCCALLSBURG_CITY = "47775"
MCCAUSLAND_CITY = "47820"
MCCLELLAND_CITY = "47865"
MCGREGOR_CITY = "48000"
MCINTIRE_CITY = "48045"
MECHANICSVILLE_CITY = "50700"
MEDIAPOLIS_CITY = "50790"
MELBOURNE_CITY = "50880"
MELCHER_DALLAS_CITY = "50935"
MELROSE_CITY = "50970"
MELVIN_CITY = "51060"
MENLO_CITY = "51105"
MERIDEN_CITY = "51150"
MERRILL_CITY = "51375"
MESERVEY_CITY = "51420"
MEYER_CDP = "51510"
MIDDLE_AMANA_CDP = "51600"
MIDDLETOWN_CITY = "51735"
MILES_CITY = "52050"
MILFORD_CITY = "52095"
MILLER_CDP = "52140"
MILLERSBURG_CITY = "52230"
MILLERTON_CITY = "52275"
MILO_CITY = "52455"
MILTON_CITY = "52500"
MINBURN_CITY = "52545"
MINDEN_CITY = "52590"
MINEOLA_CDP = "52635"
MINGO_CITY = "52815"
MISSOURI_VALLEY_CITY = "52860"
MITCHELL_CITY = "52905"
MITCHELLVILLE_CITY = "52950"
MODALE_CITY = "52995"
MONA_CDP = "53085"
MONDAMIN_CITY = "53175"
MONMOUTH_CITY = "53265"
MONONA_CITY = "53310"
MONROE_CITY = "53355"
MONTEZUMA_CITY = "53490"
MONTICELLO_CITY = "53625"
MONTOUR_CITY = "53670"
MONTPELIER_CDP = "53715"
MONTROSE_CITY = "53760"
MOOAR_CDP = "53805"
MOORHEAD_CITY = "53850"
MOORLAND_CITY = "53895"
MORAVIA_CITY = "53985"
MORLEY_CITY = "54030"
MORNING_SUN_CITY = "54120"
MORRISON_CITY = "54165"
MOSCOW_CDP = "54345"
MOULTON_CITY = "54390"
MOUNT_AUBURN_CITY = "54435"
MOUNT_AYR_CITY = "54480"
MOUNT_PLEASANT_CITY = "54705"
MOUNT_STERLING_CDP = "54750"
MOUNT_UNION_CDP = "54795"
MOUNT_VERNON_CITY = "54840"
MOVILLE_CITY = "54930"
MURRAY_CITY = "55065"
MUSCATINE_CITY = "55110"
MYSTIC_CITY = "55200"
NASHUA_CITY = "55335"
NEMAHA_CITY = "55515"
NEOLA_CITY = "55560"
NEVADA_CITY = "55695"
NEW_ALBIN_CITY = "55785"
NEW_HAMPTON_CITY = "56100"
NEW_HARTFORD_CITY = "56145"
NEW_HAVEN_CDP = "56190"
NEW_LIBERTY_CITY = "56280"
NEW_LONDON_CITY = "56325"
NEW_MARKET_CITY = "56370"
NEW_PROVIDENCE_CITY = "56415"
NEW_SHARON_CITY = "56460"
NEW_VIENNA_CITY = "56550"
NEW_VIRGINIA_CITY = "56595"
NEWELL_CITY = "55965"
NEWHALL_CITY = "56055"
NEWTON_CITY = "56505"
NICHOLS_CITY = "56685"
NODAWAY_CITY = "56865"
NORA_SPRINGS_CITY = "56910"
NORTH_BUENA_VISTA_CITY = "57135"
NORTH_ENGLISH_CITY = "57225"
NORTH_LIBERTY_CITY = "57360"
NORTH_WASHINGTON_CITY = "57495"
NORTHBORO_CITY = "57045"
NORTHWOOD_CITY = "57630"
NORWALK_CITY = "57675"
NORWAY_CITY = "57720"
NUMA_CITY = "57945"
OAK_HILLS_CDP = "58048"
OAKLAND_ACRES_CITY = "58170"
OAKLAND_CITY = "58080"
OAKVILLE_CITY = "58395"
OCHEYEDAN_CITY = "58530"
ODEBOLT_CITY = "58575"
OELWEIN_CITY = "58620"
OGDEN_CITY = "58665"
OKOBOJI_CITY = "58710"
OLDS_CITY = "58890"
OLIN_CITY = "58980"
OLLIE_CITY = "59070"
ONAWA_CITY = "59115"
ONSLOW_CITY = "59250"
ORANGE_CITY_CITY = "59475"
ORCHARD_CITY = "59520"
ORIENT_CITY = "59565"
ORLEANS_CITY = "59655"
OSAGE_CITY = "59745"
OSCEOLA_CITY = "59835"
OSKALOOSA_CITY = "59925"
OSSIAN_CITY = "59970"
OSTERDOCK_CITY = "60015"
OTHO_CITY = "60105"
OTO_CITY = "60240"
OTRANTO_CDP = "60285"
OTTOSEN_CITY = "60420"
OTTUMWA_CITY = "60465"
OWASA_CITY = "60555"
OXFORD_JUNCTION_CITY = "60690"
OXFORD_CITY = "60645"
OYENS_CITY = "60780"
PACIFIC_JUNCTION_CITY = "60825"
PACKWOOD_CITY = "60915"
PALMER_CITY = "61050"
PALO_CITY = "61230"
PANAMA_CITY = "61275"
PANORA_CITY = "61320"
PANORAMA_PARK_CITY = "61365"
PARK_VIEW_CDP = "61725"
PARKERSBURG_CITY = "61590"
PARNELL_CITY = "61770"
PATON_CITY = "61815"
PATTERSON_CITY = "61860"
PAULLINA_CITY = "61905"
PELLA_CITY = "62040"
PEOSTA_CITY = "62130"
PERCIVAL_CDP = "62175"
PERRY_CITY = "62355"
PERSIA_CITY = "62445"
PETERSON_CITY = "62625"
PIERSON_CITY = "62760"
PILOT_MOUND_CITY = "62850"
PISGAH_CITY = "63075"
PLAINFIELD_CITY = "63210"
PLAINVIEW_CDP = "63300"
PLANO_CITY = "63345"
PLEASANT_HILL_CITY = "63525"
PLEASANT_PLAIN_CITY = "63615"
PLEASANTON_CITY = "63570"
PLEASANTVILLE_CITY = "63750"
PLOVER_CITY = "63840"
PLYMOUTH_CITY = "63885"
POCAHONTAS_CITY = "63975"
POLK_CITY_CITY = "64020"
POMEROY_CITY = "64065"
POPEJOY_CITY = "64110"
PORTLAND_CDP = "64155"
PORTSMOUTH_CITY = "64200"
POSTVILLE_CITY = "64290"
PRAIRIE_CITY_CITY = "64470"
PRAIRIEBURG_CITY = "64425"
PRESCOTT_CITY = "64560"
PRESTON_CITY = "64605"
PRIMGHAR_CITY = "64650"
PRINCETON_CITY = "64740"
PROMISE_CITY_CITY = "64875"
PROTIVIN_CITY = "65010"
PULASKI_CITY = "65055"
QUASQUETON_CITY = "65235"
QUIMBY_CITY = "65280"
RADCLIFFE_CITY = "65370"
RAKE_CITY = "65415"
RALSTON_CITY = "65505"
RANDALIA_CITY = "65550"
RANDALL_CITY = "65595"
RANDOLPH_CITY = "65640"
RATHBUN_CITY = "65730"
RAYMOND_CITY = "65820"
READLYN_CITY = "65910"
REASNOR_CITY = "65955"
RED_OAK_CITY = "66135"
REDDING_CITY = "66000"
REDFIELD_CITY = "66045"
REINBECK_CITY = "66315"
REMBRANDT_CITY = "66360"
REMSEN_CITY = "66405"
RENWICK_CITY = "66450"
RHODES_CITY = "66540"
RICEVILLE_CITY = "66585"
RICHLAND_CITY = "66720"
RICKARDSVILLE_CITY = "66810"
RICKETTS_CITY = "66855"
RIDGEWAY_CITY = "67035"
RINARD_CITY = "67125"
RINGSTED_CITY = "67170"
RIPPEY_CITY = "67215"
RIVER_SIOUX_CDP = "67530"
RIVERDALE_CITY = "67350"
RIVERSIDE_CITY = "67440"
RIVERTON_CITY = "67575"
ROBINS_CITY = "67800"
ROCHESTER_CDP = "67890"
ROCK_FALLS_CITY = "68025"
ROCK_RAPIDS_CITY = "68160"
ROCK_VALLEY_CITY = "68205"
ROCKFORD_CITY = "68070"
ROCKWELL_CITY_CITY = "68295"
ROCKWELL_CITY = "68250"
RODMAN_CITY = "68340"
RODNEY_CITY = "68385"
ROLAND_CITY = "68475"
ROLFE_CITY = "68520"
ROME_CITY = "68565"
ROSE_HILL_CITY = "68700"
ROSEVILLE_CDP = "68800"
ROSSIE_CITY = "68925"
ROWAN_CITY = "69015"
ROWLEY_CITY = "69060"
ROYAL_CITY = "69105"
RUDD_CITY = "69195"
RUNNELLS_CITY = "69240"
RUSSELL_CITY = "69285"
RUTHVEN_CITY = "69330"
RUTLAND_CITY = "69375"
RYAN_CITY = "69465"
SABULA_CITY = "69510"
SAC_CITY_CITY = "69645"
SAGEVILLE_CITY = "69690"
SALEM_CITY = "70230"
SALIX_CITY = "70320"
SANBORN_CITY = "70410"
SANDUSKY_CDP = "70545"
SANDYVILLE_CITY = "70590"
SAYLORVILLE_CDP = "70995"
SCARVILLE_CITY = "71040"
SCHALLER_CITY = "71085"
SCHLESWIG_CITY = "71130"
SCRANTON_CITY = "71310"
SEARSBORO_CITY = "71355"
SERGEANT_BLUFF_CITY = "71625"
SEXTON_CDP = "71715"
SEYMOUR_CITY = "71760"
SHAMBAUGH_CITY = "71895"
SHANNON_CITY_CITY = "71940"
SHARPSBURG_CITY = "72075"
SHEFFIELD_CITY = "72210"
SHELBY_CITY = "72300"
SHELDAHL_CITY = "72345"
SHELDON_CITY = "72390"
SHELL_ROCK_CITY = "72435"
SHELLSBURG_CITY = "72480"
SHENANDOAH_CITY = "72525"
SHERRILL_CITY = "72660"
SHUEYVILLE_CITY = "72840"
SIBLEY_CITY = "72975"
SIDNEY_CITY = "73065"
SIGOURNEY_CITY = "73110"
SILVER_CITY_CITY = "73155"
SIOUX_CENTER_CITY = "73290"
SIOUX_CITY_CITY = "73335"
SIOUX_RAPIDS_CITY = "73425"
SLATER_CITY = "73515"
SLOAN_CITY = "73605"
SMITHLAND_CITY = "73650"
SOLDIER_CITY = "73785"
SOLON_CITY = "73875"
SOMERS_CITY = "73920"
SOUTH_AMANA_CDP = "73965"
SOUTH_ENGLISH_CITY = "74055"
SPENCER_CITY = "74280"
SPERRY_CDP = "74325"
SPILLVILLE_CITY = "74370"
SPIRIT_LAKE_CITY = "74415"
SPRAGUEVILLE_CITY = "74460"
SPRING_HILL_CITY = "74685"
SPRINGBROOK_CITY = "74505"
SPRINGVILLE_CITY = "74775"
ST_ANSGAR_CITY = "69735"
ST_ANTHONY_CITY = "69780"
ST_BENEDICT_CDP = "69825"
ST_CHARLES_CITY = "69915"
ST_DONATUS_CITY = "69960"
ST_JOSEPH_CDP = "70005"
ST_LUCAS_CITY = "70050"
ST_MARYS_CITY = "70095"
ST_OLAF_CITY = "70140"
ST_PAUL_CITY = "70185"
STACYVILLE_CITY = "74820"
STANHOPE_CITY = "74910"
STANLEY_CITY = "74955"
STANTON_CITY = "75000"
STANWOOD_CITY = "75045"
STATE_CENTER_CITY = "75135"
STEAMBOAT_ROCK_CITY = "75180"
STOCKPORT_CITY = "75405"
STOCKTON_CITY = "75450"
STONE_CITY_CDP = "75540"
STORM_LAKE_CITY = "75630"
STORY_CITY_CITY = "75675"
STOUT_CITY = "75720"
STRATFORD_CITY = "75810"
STRAWBERRY_POINT_CITY = "75855"
STRUBLE_CITY = "75945"
STUART_CITY = "75990"
SULLY_CITY = "76035"
SUMNER_CITY = "76260"
SUN_VALLEY_LAKE_CDP = "76415"
SUPERIOR_CITY = "76440"
SUTHERLAND_CITY = "76485"
SWALEDALE_CITY = "76620"
SWAN_CITY = "76665"
SWEA_CITY_CITY = "76755"
SWEDESBURG_CDP = "76800"
SWISHER_CITY = "76890"
TABOR_CITY = "76935"
TAMA_CITY = "77115"
TEMPLETON_CITY = "77340"
TENNANT_CITY = "77430"
TERRIL_CITY = "77520"
THAYER_CITY = "77565"
THOMPSON_CITY = "77745"
THOR_CITY = "77790"
THORNBURG_CITY = "77835"
THORNTON_CITY = "77880"
THURMAN_CITY = "77970"
TIFFIN_CITY = "78060"
TINGLEY_CITY = "78195"
TIPTON_CITY = "78285"
TITONKA_CITY = "78330"
TOETERVILLE_CDP = "78465"
TOLEDO_CITY = "78510"
TORONTO_CITY = "78600"
TRAER_CITY = "78735"
TRENTON_CDP = "78780"
TREYNOR_CITY = "78825"
TRIPOLI_CITY = "78915"
TRUESDALE_CITY = "79095"
TRURO_CITY = "79140"
TURIN_CITY = "79185"
TWIN_LAKES_CDP = "79335"
UDELL_CITY = "79410"
UNDERWOOD_CITY = "79500"
UNION_CITY = "79545"
UNIONVILLE_CITY = "79680"
UNIVERSITY_HEIGHTS_CITY = "79770"
UNIVERSITY_PARK_CITY = "79815"
URBANA_CITY = "79905"
URBANDALE_CITY = "79950"
UTE_CITY = "79995"
VAIL_CITY = "80130"
VALERIA_CITY = "80175"
VAN_HORNE_CITY = "80400"
VAN_METER_CITY = "80445"
VAN_WERT_CITY = "80490"
VARINA_CITY = "80535"
VENTURA_CITY = "80580"
VICTOR_CITY = "80805"
VILLISCA_CITY = "80985"
VINCENT_CITY = "81075"
VINING_CITY = "81120"
VINTON_CITY = "81210"
VOLGA_CITY = "81345"
WADENA_CITY = "81570"
WAHPETON_CITY = "81615"
WALCOTT_CITY = "81705"
WALFORD_CITY = "81840"
WALKER_CITY = "81885"
WALL_LAKE_CITY = "82020"
WALLINGFORD_CITY = "81975"
WALNUT_CITY = "82065"
WAPELLO_CITY = "82200"
WASHBURN_CDP = "82290"
WASHINGTON_CITY = "82335"
WASHTA_CITY = "82380"
WATERLOO_CITY = "82425"
WATERVILLE_CITY = "82470"
WATKINS_CDP = "82515"
WAUCOMA_CITY = "82650"
WAUKEE_CITY = "82695"
WAUKON_CITY = "82740"
WAVERLY_CITY = "82875"
WAYLAND_CITY = "82965"
WEBB_CITY = "83010"
WEBSTER_CITY_CITY = "83145"
WEBSTER_CITY = "83055"
WELDON_CITY = "83190"
WELLMAN_CITY = "83280"
WELLSBURG_CITY = "83325"
WELTON_CITY = "83370"
WESLEY_CITY = "83415"
WEST_AMANA_CDP = "83505"
WEST_BEND_CITY = "83550"
WEST_BRANCH_CITY = "83595"
WEST_BURLINGTON_CITY = "83685"
WEST_CHESTER_CITY = "83775"
WEST_DES_MOINES_CITY = "83910"
WEST_LIBERTY_CITY = "84315"
WEST_OKOBOJI_CITY = "84450"
WEST_POINT_CITY = "84585"
WEST_UNION_CITY = "84765"
WESTFIELD_CITY = "84090"
WESTGATE_CITY = "84180"
WESTON_CDP = "84495"
WESTPHALIA_CITY = "84540"
WESTSIDE_CITY = "84630"
WESTWOOD_CITY = "84835"
WEVER_CDP = "84855"
WHAT_CHEER_CITY = "84900"
WHEATLAND_CITY = "84945"
WHITING_CITY = "85215"
WHITTEMORE_CITY = "85260"
WHITTEN_CITY = "85305"
WILLEY_CITY = "85710"
WILLIAMS_CITY = "85800"
WILLIAMSBURG_CITY = "85845"
WILLIAMSON_CITY = "85935"
WILTON_CITY = "86070"
WINDSOR_HEIGHTS_CITY = "86250"
WINFIELD_CITY = "86385"
WINTERSET_CITY = "86520"
WINTHROP_CITY = "86565"
WIOTA_CITY = "86610"
WODEN_CITY = "86700"
WOODBINE_CITY = "86835"
WOODBURN_CITY = "86880"
WOODWARD_CITY = "86970"
WOOLSTOCK_CITY = "87015"
WORTHINGTON_CITY = "87060"
WYOMING_CITY = "87240"
YALE_CITY = "87285"
YARMOUTH_CDP = "87330"
YETTER_CITY = "87375"
YORKTOWN_CITY = "87420"
ZEARING_CITY = "87555"
ZWINGLE_CITY = "87690"
